
local ArenaLayer = class("ArenaLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function ArenaLayer.create()
    local layer = ArenaLayer.new()
    layer:createLayerMenu()
    return layer
end

function ArenaLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
	self.selectTag = nil
    self.schedulerID = nil
    self.mainNode = nil
    self.ranking = 0
    self.timesLabel = nil
end

function ArenaLayer:remove()
    cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Arena_List")
    self:removeFromParent()
end

function ArenaLayer:battle()
    if self.ranking > 0 then
        --wd.TranscodingSend:setArenaBattle(self.ranking)
        self:getParent():setArenaBattle(self.ranking,self.rankerName,self.rankerLevel)
        self:remove()
    end
end

function ArenaLayer:getChallengeReward(ranking)
    local stone = 0
    if ranking <= 1 then
        stone = 25
    elseif ranking <= 5 then
        stone = 21
    elseif ranking <= 20 then
        stone = 18
    elseif ranking <= 50 then
        stone = 16
    elseif ranking <= 100 then
        stone = 14
    elseif ranking <= 200 then
        stone = 12
    elseif ranking <= 300 then
        stone = 10
    elseif ranking <= 500 then
        stone = 8
    elseif ranking <= 1000 then
        stone = 7
    elseif ranking <= 30000 then
        stone = 5
    end
    
    return stone
end

function ArenaLayer:getArenaReward(ranking)
    local gem = 0
    local stone = 0
	local drug = 0
    
    if ranking <= 1 then
        gem = 300
        stone = 100
		drug = 300
    elseif ranking <= 5 then
        gem = 250
        stone = 90
		drug = 250
    elseif ranking <= 20 then
        gem = 230
        stone = 80
		drug = 230
    elseif ranking <= 50 then
        gem = 210
        stone = 70
		drug = 210
    elseif ranking <= 100 then
        gem = 180
        stone = 60
		drug = 180
    elseif ranking <= 200 then
        gem = 160
        stone = 50
		drug = 160
    elseif ranking <= 300 then
        gem = 140
        stone = 40
		drug = 140
    elseif ranking <= 500 then
        gem = 120
        stone = 30
		drug = 120
    elseif ranking <= 1000 then
        gem = 100
        stone = 30
		drug = 100
    elseif ranking <= 30000 then
        gem = 100
        stone = 30
		drug = 100
    end

    return gem,stone,drug

end

function ArenaLayer:showSelfSprite()
    local gladiator = wd.GlobalData:getInstance():getRoleData()

    local playerPanel = tolua.cast(ccui.Helper:seekWidgetByName(self.mainNode,"Panel_Player"), "ccui.Widget")
    
    local rankingLabel = tolua.cast(ccui.Helper:seekWidgetByName(playerPanel,"Ranking_Label"), "ccui.Text")
    local ranking = gladiator:getArenaRanking()
    if ranking > 0 and ranking < 3000 then
        rankingLabel:setString(string.format("%d",ranking))
    else
        rankingLabel:setString(">3000")
    end
    
    local gem,stone,drug = self:getArenaReward(ranking)
    
    local gemLabel = tolua.cast(ccui.Helper:seekWidgetByName(playerPanel,"Gem_Label"), "ccui.Text")
    gemLabel:setString(string.format("元宝X%d  天工神石X%d  引魂丹X%d",gem,stone,drug))
    
    --[[local stoneLabel = tolua.cast(ccui.Helper:seekWidgetByName(playerPanel,"Stone_Label"), "ccui.Text")
    stoneLabel:setString(string.format("黑铁矿石X%d",stone))--]]
    
    self.timesLabel = tolua.cast(ccui.Helper:seekWidgetByName(playerPanel,"Times_Label"), "ccui.Text")
    self.timesLabel:setString(string.format("%d",gladiator:getChallengeNumber()))

    local playerSprite = tolua.cast(playerPanel:getChildByName("Challenge_Button"):getChildByName("Player_Sprite"), "cc.Sprite")
    playerSprite:setSpriteFrame(wd.getPlayerImageName(gladiator:getOccupation(), gladiator:getSex()))
    if gladiator:getSex() == 1 then
        playerSprite:setFlippedX(true)
    else
        playerSprite:setFlippedX(false)
    end
    playerSprite:setVisible(true)
    
    local playerBtn = tolua.cast(playerSprite:getChildByName("Player_Button"), "ccui.Button")
    playerBtn:setEnabled(true)
    playerBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                local layerClass = require("src.game.arena.PlayerLayer")
                local layer = layerClass.create()
                layer:createLayerMenu(wd.PlayerType.SELF)
                self:addChild(layer)
            end
        end
    )
	
	local showBtn = tolua.cast(ccui.Helper:seekWidgetByName(playerPanel,"ArenaShow_Button"), "ccui.Button")
    showBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                local layerClass = require("src.game.arena.ArenaShowLayer")
                local layer = layerClass.create()
                self:addChild(layer)
            end
        end
    )

    local playerNode = tolua.cast(playerPanel:getChildByName("Challenge_Button"):getChildByName("Player_Node"), "cc.Node")
    playerNode:setVisible(true)

    local nameLabel = tolua.cast(playerNode:getChildByName("Name_Label"), "ccui.Text")
    nameLabel:setString(gladiator:getName())

    local levelLabel = tolua.cast(playerNode:getChildByName("Level_Label"), "ccui.TextBMFont")
    levelLabel:setString(string.format("Lv%d", gladiator:getLevel()))

    local powerLabel = tolua.cast(playerNode:getChildByName("Power_Label"), "ccui.TextBMFont")
    powerLabel:setString(string.format("%d",gladiator:getPower()))

end

function ArenaLayer:showEnemySprite(tag)

    local gladiator = wd.GlobalData:getInstance():getGladiatorData(tag)
    
    self.ranking = gladiator:getRanking()
	self.rankerName = gladiator:getName()
	self.rankerLevel = gladiator:getLevel()

    local playerPanel = tolua.cast(ccui.Helper:seekWidgetByName(self.mainNode,"Panel_Player"), "ccui.Widget")

    local selectTitle = tolua.cast(playerPanel:getChildByName("Select_Title"), "cc.Sprite")
    selectTitle:setVisible(false)
    
    local enemySprite = tolua.cast(playerPanel:getChildByName("Challenge_Button"):getChildByName("Enemy_Sprite"), "cc.Sprite")
    enemySprite:setSpriteFrame(wd.getPlayerImageName(gladiator:getOccupation(), gladiator:getSex()))
    enemySprite:setVisible(true)
    if gladiator:getSex() == 0 then
        enemySprite:setFlippedX(true)
    else
        enemySprite:setFlippedX(false)
    end
    
    local enemyBtn = tolua.cast(enemySprite:getChildByName("Enemy_Button"), "ccui.Button")
    enemyBtn:setEnabled(true)
    enemyBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                local layerClass = require("src.game.arena.PlayerLayer")
                local layer = layerClass.create()
                layer:createLayerMenu(wd.PlayerType.ENEMY)
                self:addChild(layer)
                
                wd.TranscodingSend:getPlayerData(gladiator:getRoleId())
            end
        end
    )
    
    local enemyNode = tolua.cast(playerPanel:getChildByName("Challenge_Button"):getChildByName("Enemy_Node"), "cc.Node")
    enemyNode:setVisible(true)
    
    local nameLabel = tolua.cast(enemyNode:getChildByName("Name_Label"), "ccui.Text")
    nameLabel:setString(gladiator:getName())
    
    local levelLabel = tolua.cast(enemyNode:getChildByName("Level_Label"), "ccui.TextBMFont")
    levelLabel:setString(string.format("Lv%d", gladiator:getLevel()))
    
    local powerLabel = tolua.cast(enemyNode:getChildByName("Power_Label"), "ccui.TextBMFont")
    powerLabel:setString(string.format("%d",gladiator:getPower()))
end


function ArenaLayer:showArenaList()
    local panel = tolua.cast(ccui.Helper:seekWidgetByName(self.mainNode,"Panel_Challenge"), "ccui.Widget")
    panel:removeAllChildren()
    
    local number = wd.GlobalData:getInstance():getGladiatorCount()
    
    local function attrCallback(sender,eventType)
        if eventType == ccui.TouchEventType.ended then
			wd.setSelectBox(panel,self.selectTag,sender:getTag())
			self.selectTag = sender:getTag()
            self:showEnemySprite(sender:getTag())
        end
    end
    
    local panelHeight = panel:getContentSize().height
    
        
    for i=0,number-1 do
        local gladiator = wd.GlobalData:getInstance():getGladiatorData(i)
        
        local btn = ccui.Button:create("arena_player_box.png", "arena_player_box.png", "", ccui.TextureResType.plistType)
        btn:setAnchorPoint(cc.p(0,0))
        btn:setPosition(0, panelHeight - 106*(i+1))
        btn:setTag(i)
        btn:addTouchEventListener(attrCallback)
        btn:setContentSize(cc.size(304,102))
        panel:addChild(btn)

        
        local gladiatorNode = tolua.cast(cc.CSLoader:createNode("ui/arena/ArenaNode.csb"),"ccui.Widget")
        btn:addChild(gladiatorNode)
        gladiatorNode:setTag(i)       
        local image = tolua.cast(gladiatorNode:getChildByName("Head_Sprite"), "cc.Sprite")
        image:setSpriteFrame(wd.getHeadImageName(gladiator:getOccupation(), gladiator:getSex()))
        
        local job = tolua.cast(gladiatorNode:getChildByName("Job_Title"), "cc.Sprite")
        job:setSpriteFrame(wd.getEquipTitleName(gladiator:getOccupation()))
        
        local nameLabel = tolua.cast(gladiatorNode:getChildByName("Name_Label"), "ccui.Text")
        nameLabel:setString(gladiator:getName())
        
        local powerLabel = tolua.cast(gladiatorNode:getChildByName("Power_Label"), "ccui.Text")
        powerLabel:setString(string.format("%d",gladiator:getPower()))

        local rankingLabel = tolua.cast(gladiatorNode:getChildByName("Ranking_Label"), "ccui.TextAtlas")
        rankingLabel:setString(string.format("%d",gladiator:getRanking()))
        
        local reward = self:getChallengeReward(gladiator:getRanking())
        
        local rewardLabel = tolua.cast(gladiatorNode:getChildByName("Reward_Label"), "ccui.Text")
        rewardLabel:setString(string.format("+%d黑铁矿石",reward))
        
    end
    

    if self.selectTag ~= nil then
        wd.setSelectBox(panel,self.selectTag,self.selectTag)
    end

end


function ArenaLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/arena/ArenaScene.csb"), "ccui.Widget")
    self:addChild(node)

    self.mainNode = node

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)

    local backBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Back_Button"), "ccui.Widget")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				local event = cc.EventCustom:new("Check_New_Tip")
				cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
                self:remove()
            end
        end
    )
	
    local helpBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Help_Button"), "ccui.Widget")
    helpBtn:setPressedActionEnabled(true)
    helpBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                local layerClass = require("src.game.setting.HelpLayer")
				local layer = layerClass.create(wd.helpType.Sub,wd.helpTag.Arena)
				self:addChild(layer)
            end
        end
    )


    local rankingBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Ranking_Button"), "ccui.Button")
    rankingBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                local layerClass = require("src.game.arena.ArenaRankingLayer")
                local layer = layerClass.create()
                self:getParent():addChild(layer)
                self:remove()
            end
        end
    )
    
    local playerSprite = node:getChildByName("Panel_Box"):getChildByName("Panel_Player"):getChildByName("Challenge_Button"):getChildByName("Player_Sprite")
    local playerBtn = tolua.cast(playerSprite:getChildByName("Player_Button"), "ccui.Button")
    playerBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                local layerClass = require("src.game.arena.PlayerLayer")
                local layer = layerClass.create()
                self:addChild(layer)
            end
        end
    )
    
    local changeBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Change_Button"), "ccui.Button")
    changeBtn:setPressedActionEnabled(true)
    changeBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Arena_List")
                local layerClass = require("src.game.arena.ArenaLayer")
                local layer = layerClass.create()
                self:getParent():addChild(layer)
                self:removeFromParent()
            end
        end
    )
    
    local challengeBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Challenge_Button"), "ccui.Button")
    challengeBtn:setPressedActionEnabled(true)
    challengeBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                if wd.GlobalData:getInstance():getRoleData():getChallengeNumber() > 0 then
                    self:battle()
                else
                    wd.showRichTips(4,"挑战次数已用完")
                end
            end
        end
    )
    
    local buyBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"BuyChallenge_Button"), "ccui.Button")
    buyBtn:setPressedActionEnabled(true)
    buyBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                local layerClass = require("src.tips.TipsBoxLayer")
                local msgTable = {}
                local msg = {}
                local role = wd.GlobalData:getInstance():getRoleData()
                if role:getChallengeBuy() > 0  then
                    table.insert(msg,"是否花")
                    table.insert(msg,string.format("{y=[%d元宝]}",20))
                    table.insert(msg,"购买")
                    table.insert(msg,string.format("{g=[%d次]}",1))
                    table.insert(msg,"挑战?")
                    table.insert(msgTable,msg)
                    
                    msg = {}
                    table.insert(msg,"当前")
                    table.insert(msg,string.format("{y=[Vip%d]}",role:getVip()))
                    table.insert(msg,"还可购买")
                    table.insert(msg,string.format("{g=[%d次]}",role:getChallengeBuy()))

                else
                    table.insert(msg,"已达购买上限")
                    if role:getVip() < wd.GlobalData:getInstance():getVipXmlCount()-1 then
                        table.insert(msg,",升级Vip可提升上限")
                    end
                end
                table.insert(msgTable,msg)

                local function sureCallback()
                    if wd.GlobalData:getInstance():getRoleGem() < 20 then
                        local layerClass = require("src.game.charge.ChargeTipsScene")
                        local layer = layerClass:create()
                        self:getParent():addChild(layer)
                    else
					    wd.TranscodingSend:buyArenaChallenge()
                    end
                end
                self.tipsLayer = layerClass.create("buy_count_title.png", msgTable,sureCallback)
                self:addChild(self.tipsLayer)
            end
        end
    )
        
    self:showSelfSprite()

    local function arenaListCallback(EventCustom)
        self:showArenaList()
        
        if self.timesLabel ~= nil then
            local gladiator = wd.GlobalData:getInstance():getRoleData()
            self.timesLabel:setString(string.format("%d",gladiator:getChallengeNumber()))
        end
    end

    local listener = cc.EventListenerCustom:create("Arena_List", arenaListCallback)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
    
    wd.TranscodingSend:getArenaList()
end


return ArenaLayer