local BattleWordDataHandler = class("BattleWordDataHandler")

function BattleWordDataHandler:ctor()
	self.fontSize = nil
	self.msg = nil
	self.buffEffect = nil
	self.atkEffect = nil
	self.MPEffect = nil
	self.skillDataHandler = wd.skillHandler
	self.fightElementList = {}
	self.endElementList = {}
	self.enemyElementList = {}
	self.tickElementList = {}
	self.battleInfoList= {}
	self.offlineElementList = {}
end

function BattleWordDataHandler:getInstance()
	if not self.instance then
		self.instance = BattleWordDataHandler.new()
	end
	return self.instance
end

function BattleWordDataHandler:destroyInstance()
    if self.instance then
        self.instance = nil
    end
end

function BattleWordDataHandler:setElementFontSize(fontSize)
	self.fontSize = fontSize
end

function BattleWordDataHandler:setBattleTable(battleTable)
	self.battleTable = battleTable
end


function BattleWordDataHandler:getFightElementList()
	return self.fightElementList
end

function BattleWordDataHandler:getEndElementList()
	return self.endElementList
end

function BattleWordDataHandler:getEnemyElementList()
	return self.enemyElementList
end

function BattleWordDataHandler:getTickElementList()
	return self.tickElementList
end

function BattleWordDataHandler:setTotalMsg() 
	local totalMsg
	if self.msg then
		if self.buffEffect then
			if self.dodOccurFlag then
				totalMsg = string.format("%s%s",self.msg,self.atkEffect)
			else
				if self.MPEffect then
					totalMsg = string.format("%s 法力%s%s",self.msg,self.MPEffect,self.buffEffect)
				else
					totalMsg = string.format("%s%s",self.msg,self.buffEffect)
				end
				self.MPEffect = nil
			end
			self.buffEffect = nil
		else
			if self.atkEffect then
				totalMsg = string.format("%s%s",self.msg,self.atkEffect)
			else
				totalMsg = self.msg
			end
		end
	end
	if totalMsg then
		table.insert(self.fightElementList,self:msgParser(totalMsg))
	end
	self.msg = nil
	self.atkEffect = nil
	self.MPEffect = nil
end

function BattleWordDataHandler:resetElementList()
	self.fightElementList = {}
	self.endElementList = {}
	self.enemyElementList = {}
	self.tickElementList = {}
end

function BattleWordDataHandler:setAttackMsg(round,attack,oneAction)
	
	-- 取数据
	local battleActionInfo = {}
	local atker_Team = wd.GlobalData:getInstance():getAttackerTeam(round,attack,oneAction)
	local target_Team  = wd.GlobalData:getInstance():getTargetTeam(round,attack,oneAction)
	local type = wd.GlobalData:getInstance():getBattleActionType(round,attack,oneAction)
	local atker = wd.GlobalData:getInstance():getBattleActionAtkerTag(round,attack,oneAction)
    local target = wd.GlobalData:getInstance():getBattleActionDestTag(round,attack,oneAction)
	
	local skillId = wd.GlobalData:getInstance():getBattleActionSkill(round,attack,oneAction)
	local value = wd.GlobalData:getInstance():getBattleActionValue(round,attack,oneAction)
	local passiveSkillId = wd.GlobalData:getInstance():getBattleActionPassiveSkillId(round,attack,oneAction)
	
	battleActionInfo["round"] = round
	battleActionInfo["atker_Team"] = atker_Team
	battleActionInfo["target_Team"] = target_Team
	battleActionInfo["atker_Pos"] = atker
	battleActionInfo["target_Pos"] = target
	battleActionInfo["atker"] = self.battleTable[atker].name
	battleActionInfo["target"] = self.battleTable[target].name
	battleActionInfo["skill"] = skillId
	battleActionInfo["passiveSkill"] = passiveSkillId
	battleActionInfo["type"] = type
	battleActionInfo["value"] = value
	
	
	if atker_Team == target_Team then		-- 作用自己身上
		if type == wd.ActionType.HP_CHANGE and value < 0 then
			-- 道士技能回血
			if math.abs(battleActionInfo["passiveSkill"] - 360001) < 100 then
				self:setReStoreMsgByArg(battleActionInfo)
			end
			
		elseif type == wd.ActionType.ADD_BUFF then
			if battleActionInfo["skill"] == 0 and battleActionInfo["passiveSkill"] ~= 0 and battleActionInfo["value"] == 2 then
				self:setSpecialBuffEffect(battleActionInfo)
			elseif value ~= 9 and value ~= 17 and value ~= 18 and value ~= 20 then
				-- 获得增益效果
				self:setSelfBuffEffect(battleActionInfo)
			end
			
		elseif type == wd.ActionType.STRIKE_BACK then
			-- 反震
			self:setSpecialAttack(battleActionInfo)
		end
	else	-- 作用目标身上
		if type >= wd.ActionType.HP_CHANGE and type <= wd.ActionType.CRIT_OCCUR  then
			if type == wd.ActionType.MP_CHANGE then
				-- 护体
				self:setMPChange(battleActionInfo)
			else
				-- 基础战斗
				self:setBaseBattle(battleActionInfo)
			end
			
		elseif type == wd.ActionType.ADD_BUFF then
			-- 给对方上buff
			self:setTargetBuffEffect(battleActionInfo)
		elseif type == wd.ActionType.DOUBLE_HIT  then
			self:setSpecialAttack(battleActionInfo)
		elseif type == wd.ActionType.RAIN_HP then
			self:setRainMsg(battleActionInfo)
		end
	end
	table.insert(self.battleInfoList,battleActionInfo)
end

function BattleWordDataHandler:getBattleInfoList()
	return self.battleInfoList
end

function BattleWordDataHandler:resetBattleInfoList()
	self.battleInfoList = {}
end

-- 基础战斗
function BattleWordDataHandler:setBaseBattle(battleActionInfo)
	if battleActionInfo["atker"] == "" and battleActionInfo["target"] == "" then
		return
	end
	local atkStr,tarStr,skillStr,valueStr
	
	-- 发起者和目标
	if battleActionInfo["atker_Team"] == wd.PlayerType.SELF then
		atkStr = string.format("{a=[%s]}","你")
		tarStr = string.format("{d=[%s]}",battleActionInfo["target"])
	elseif battleActionInfo["target_Team"] ==  wd.PlayerType.SELF then
		atkStr = string.format("{d=[%s]}",battleActionInfo["atker"])
		tarStr = string.format("{a=[%s]}","你")
	end
	
	-- 技能
	if battleActionInfo["skill"] == 0 then
		skillStr = string.format("{s=[%s]}","普通攻击")
	elseif battleActionInfo["skill"] then
		local skillName = self.skillDataHandler:getSkillNameBySkillId(battleActionInfo["skill"])
		if skillName then
			skillStr = string.format("{s=[%s]}",skillName)
		end
	end
	
	-- 攻击类型
	if battleActionInfo["type"] then
		if battleActionInfo["type"] == wd.ActionType.HP_CHANGE then
			self.atkEffect = ""
			self.dodOccurFlag = false
		else
			if battleActionInfo["type"] == wd.ActionType.DOD_OCCUR then
				self.dodOccurFlag = true
			else
				self.dodOccurFlag = false
			end
			-- 闪避，暴击
			self.atkEffect = string.format("{t=[(%s)]}",wd.actionTypeString(battleActionInfo["type"]))
		end
	end
	
	-- 伤害值
	if battleActionInfo["value"] then
		valueStr = string.format("{v=[-%s],c=[%s]}",battleActionInfo["value"],"HP")
	end
	self.msg = string.format("%s使用了%s对%s造成了伤害，血量%s",atkStr,skillStr,tarStr,valueStr)
	self:setTotalMsg()
end

-- 护体
function BattleWordDataHandler:setMPChange(battleActionInfo)
	self.buffEffect = string.format("{t=[(%s)]}","护体")
	self.MPEffect = string.format("{v=[-%s],c=[%s]}",battleActionInfo["value"],"MP")
end


-- 给对方上buff
function BattleWordDataHandler:setTargetBuffEffect(battleActionInfo)
	if battleActionInfo["value"] then
		local buffItem = self.skillDataHandler:getBuffItemById(battleActionInfo["value"])
		if buffItem then
			local buffName = buffItem:getName()
			self.buffEffect = string.format("{t=[(%s)]}",buffName)
		end
	end
end

-- 连击反震
function BattleWordDataHandler:setSpecialAttack(battleActionInfo)
	if battleActionInfo["atker"] == "" and battleActionInfo["target"] == "" then
		return
	end
	local atkStr,tarStr,valueStr,effectStr,skillStr
	
	-- 发起者和目标
	if battleActionInfo["atker_Team"] == wd.PlayerType.SELF or battleActionInfo["atker_Team"] == battleActionInfo["target_Team"] then
		atkStr = string.format("{a=[%s]}","你")
		tarStr = string.format("{d=[%s]}",battleActionInfo["target"])
	elseif battleActionInfo["target_Team"] ==  wd.PlayerType.SELF or battleActionInfo["atker_Team"] == battleActionInfo["target_Team"] then
		atkStr = string.format("{d=[%s]}",battleActionInfo["atker"])
		tarStr = string.format("{a=[%s]}","你")
	end
	-- 类型
	effectStr = string.format("{t=[%s]}",wd.actionTypeString(battleActionInfo["type"]))
	
	-- 伤害值
	if battleActionInfo["value"] then
		valueStr = string.format("{v=[-%d],c=[%s]}",battleActionInfo["value"],"HP")
	end
	
	-- 被动技能
	if battleActionInfo["passiveSkill"] ~= 0 then
		local skillName = self.skillDataHandler:getSkillNameBySkillId(battleActionInfo["passiveSkill"])
		skillStr = string.format("{s=[%s]}",skillName)
	end
	local element
	if skillStr then
		element = self:msgParser(string.format("%s触发了%s,对%s%s了%s伤害",atkStr,skillStr,tarStr,effectStr,valueStr))
	else
		element = self:msgParser(string.format("%s触发了%s对%s造成%s伤害",atkStr,effectStr,tarStr,valueStr))
	end
	table.insert(self.fightElementList,element)
end


-- 获得增益效果
function BattleWordDataHandler:setSelfBuffEffect(battleActionInfo)
	local tarStr
	if battleActionInfo["atker_Team"] == wd.PlayerType.SELF then
		tarStr = string.format("{a=[%s]}","你")
	else
		tarStr = string.format("{d=[%s]}",battleActionInfo["atker"])
	end
	 local skillName 
	if battleActionInfo["skill"] ~= 0 then
		skillName = self.skillDataHandler:getSkillNameBySkillId(battleActionInfo["skill"])
	elseif battleActionInfo["passiveSkill"] ~= 0 then
		skillName = self.skillDataHandler:getSkillNameBySkillId(battleActionInfo["passiveSkill"])
	end
	local skillStr = string.format("{s=[%s]}",skillName)
	local element = self:msgParser(string.format("%s使用了%s",tarStr,skillStr))
	table.insert(self.fightElementList,element)
	if battleActionInfo["type"] == wd.ActionType.ADD_BUFF then
		if battleActionInfo["value"] then
			local buffItem = self.skillDataHandler:getBuffItemById(battleActionInfo["value"])
			if buffItem then
				local buffName = buffItem:getName()
				local buffStr = string.format("{t=[(%s)]}",buffName)
				element = nil
				element = self:msgParser(string.format("%s获得了有益效果%s",tarStr,buffStr))
				table.insert(self.fightElementList,element)
			end
		end
	end
end

function BattleWordDataHandler:setSpecialBuffEffect(battleActionInfo)
	local atkStr = string.format("{a=[%s]}","你")
	local tarStr = string.format("{d=[%s]}",battleActionInfo["atker"])
	local skillName = self.skillDataHandler:getSkillNameBySkillId(battleActionInfo["passiveSkill"])
	local skillStr = string.format("{s=[%s]}",skillName)
	if battleActionInfo["type"] == wd.ActionType.ADD_BUFF then
		if battleActionInfo["value"] then
			local buffItem = self.skillDataHandler:getBuffItemById(battleActionInfo["value"])
			if buffItem then
				local buffName = buffItem:getName()
				local buffStr = string.format("{t=[(%s)]}",buffName)
				local element = self:msgParser(string.format("%s触发了%s，对%s造成了%s",atkStr,skillStr,tarStr,buffStr))
				table.insert(self.fightElementList,element)
			end
		end
	end
	
end

-- 回血
function BattleWordDataHandler:setReStoreMsgByArg(battleActionInfo)
	local tarStr,skillStr
	if battleActionInfo["atker_Team"] == wd.PlayerType.SELF then
		tarStr = string.format("{a=[%s]}","你")
	else
		tarStr = string.format("{d=[%s]}",battleActionInfo["atker"])
	end	
	if battleActionInfo["passiveSkill"] ~= 0 then
		local skillName = self.skillDataHandler:getSkillNameBySkillId(battleActionInfo["passiveSkill"])
		skillStr = string.format("{s=[%s]}",skillName)
	end
	local valueStr = string.format("{v=[%d],c=[%s]}",-battleActionInfo["value"],"AddHP")
	local element = self:msgParser(string.format("%s触发了%s，回复了%s血量",tarStr,skillStr,valueStr))
	table.insert(self.fightElementList,element)
end

-- 复活
function BattleWordDataHandler:setRainMsg(battleActionInfo)
	local tarStr
	-- 发起者和目标
	if battleActionInfo["atker_Team"] == wd.PlayerType.SELF then
		tarStr = string.format("{d=[%s]}",battleActionInfo["target"])
	elseif battleActionInfo["target_Team"] ==  wd.PlayerType.SELF then
		tarStr = string.format("{a=[%s]}","你")
	end
	local effectStr = string.format("{t=[%s]}",wd.actionTypeString(battleActionInfo["type"]))
	local valueStr = string.format("{v=[%d],c=[%s]}",battleActionInfo["value"],"AddHP")
	local element = self:msgParser(string.format("%s已死亡，触发了%s，回复了%s血量",tarStr,effectStr,valueStr))
	table.insert(self.fightElementList,element)
end

-- 战斗结束
function BattleWordDataHandler:setEndMsg(endType)
	local tarStr = string.format("{a=[%s]}","你")
	local element
	if endType == "win" then
		local expStr = string.format("{i=[%d]}",wd.GlobalData:getInstance():getBattleResultExp())
		local goldStr = string.format("{i=[%d]}",wd.GlobalData:getInstance():getBattleResultGold())
		local equipStr = ""
		local equipCount = wd.GlobalData:getInstance():getBattleResultEquipListCount()
		if equipCount > 0 then
			for i=0,equipCount-1 do
				local equip = wd.GlobalData:getInstance():getFallEquipItem(i)
				if equip then
					local equipName = equip:getName()
					local color = equip:getColor()
					equipStr = equipStr..string.format("{e=[%s],c=[%d]}",equipName,color)
				end
			end
		end
		
        local soldStr = ""
        local soldCount = wd.GlobalData:getInstance():getBattleResultSoldEquipListCount()
        if soldCount > 0 then
            for i=0,soldCount-1 do
                local equip = wd.GlobalData:getInstance():getSoldEquipItem(i)
                if equip then
                    local equipName = equip:getName()
                    local color = equip:getColor()
                    soldStr = soldStr..string.format("{e=[%s],c=[%d]}",equipName,color)
                end
            end
        end
		
		local itemStr = ""
		local itemCount = wd.GlobalData:getInstance():getBattleResultItemListCount()
		if itemCount > 0 then
			for i=0,itemCount-1 do
				local item = wd.GlobalData:getInstance():getFallToolsItem(i)
				if item then
					local itemName = item:getName()
					local quantity = item:getQuantity()
					itemStr = itemStr..string.format("{i=[%s x%d]}",itemName,quantity)
				end
			end
		end
		element= self:msgParser(string.format("%s获胜了",tarStr))
		table.insert(self.endElementList,element)
		element = self:msgParser(string.format("获得经验:%s",expStr))
		table.insert(self.endElementList,element)
		element = self:msgParser(string.format("获得金钱:%s",goldStr))
		table.insert(self.endElementList,element)
		if itemStr~="" then
			element = self:msgParser(string.format("获得物品:%s",itemStr))
			table.insert(self.endElementList,element)
		end
		if equipStr~="" then
			element = self:msgParser(string.format("获得装备:%s",equipStr))
			table.insert(self.endElementList,element)
		end
        if soldStr~="" then
            element = self:msgParser(string.format("自动卖出装备:%s",soldStr))
            table.insert(self.endElementList,element)
        end
	elseif endType == "lose" then
		element = self:msgParser(string.format("%s失败了",tarStr))
		table.insert(self.endElementList,element)
	elseif endType == "levelUp" then
		element = self:msgParser(string.format("%s升级了",tarStr))
		table.insert(self.endElementList,element)
	end
end

-- 遇见敌人
function BattleWordDataHandler:setEnemyMsg(name)
	local atkStr = string.format("{a=[%s]}","你")
	local tarStr = string.format("{d=[%s]}",name)
	local element = self:msgParser(string.format("%s遇见了%s",atkStr,tarStr))
	table.insert(self.enemyElementList,element)
end

-- 倒数
function BattleWordDataHandler:setTickMsg(tickRound)
	local element 
	if tickRound == 0 then
		element = self:msgParser(string.format("正在恢复中，请等待下一场战斗开始..."))
	else
		element = self:msgParser(string.format("正在恢复中，下一场战斗即将开始(%d)...",tickRound))
	end
	table.insert(self.tickElementList,element)
end

function BattleWordDataHandler:getOfflineElementList()
	return self.offlineElementList
end

function BattleWordDataHandler:resetOfflineElementList()
	self.offlineElementList = {}
end

-- 离线信息
function BattleWordDataHandler:setOfflineData(offlineData)
	local battleNumberStr,equipSellNumberStr,equipSellPriceStr,fallExpericeStr,fallItemNumberStr,levelStr,moneyStr,offlineTimeStr,mapStr,killNumberStr,equipCountStr
	local lastMapId = wd.GlobalData:getInstance():getLastLoginMapId()
	local mapName = ""
	if lastMapId < 100 then
		mapName = wd.GlobalData:getInstance():getMapName(lastMapId)
	else
		mapName = wd.GlobalData:getInstance():getPKMapName(lastMapId-101)
	end
	if offlineData:getOfflineTime() then
		local h,m,s
		h = math.floor(offlineData:getOfflineTime()/3600)
		m = math.floor(math.abs(offlineData:getOfflineTime()-3600*h)/60)
		s = math.abs(offlineData:getOfflineTime()-h*3600-m*60)
		offlineTimeStr = string.format("{o=[%02d:%02d:%02d]}",h,m,s)
		local element = self:msgParser(string.format("你在离线的 %s 内",offlineTimeStr),cc.c3b(255,255,255))
		table.insert(self.offlineElementList,element)
	end
	if mapName and offlineData:getBattleNumber() then
		battleNumberStr = string.format("{o=[%d]}",offlineData:getBattleNumber())
		mapStr = string.format("{o=[%s]}",mapName)
		local element = self:msgParser(string.format("你在地图%s战斗了%s次",mapStr,battleNumberStr),cc.c3b(255,255,255))
		table.insert(self.offlineElementList,element)
	end
	if offlineData:getLevel() then
		levelStr = string.format("{o=[%d]}",offlineData:getLevel())
		local element = self:msgParser(string.format("等级提升到:%s",levelStr),cc.c3b(255,255,255))
		table.insert(self.offlineElementList,element)
	end
	if offlineData:getBattleNumber() then
		killNumberStr =  string.format("{o=[%d]}",offlineData:getBattleNumber())
		local element = self:msgParser(string.format("消灭怪物:%s",killNumberStr),cc.c3b(255,255,255))
		table.insert(self.offlineElementList,element)
	end
	if offlineData:getFallExperience() then
		fallExpericeStr = string.format("{o=[%d]}",offlineData:getFallExperience())
		local element = self:msgParser(string.format("获得经验:%s",fallExpericeStr),cc.c3b(255,255,255))
		table.insert(self.offlineElementList,element)
	end
	if offlineData:getMoney() then
		moneyStr =  string.format("{o=[%d]}",offlineData:getMoney())
		local element = self:msgParser(string.format("获得金币:%s",moneyStr),cc.c3b(255,255,255))
		table.insert(self.offlineElementList,element)
	end
	if offlineData:getFallItemNumber() then
		fallItemNumberStr =  string.format("{o=[%d]}",offlineData:getFallItemNumber())
		local element = self:msgParser(string.format("获得物品:%s",fallItemNumberStr),cc.c3b(255,255,255))
		table.insert(self.offlineElementList,element)
	end
	local equipStr = {
		[0] = "白色装备 X",
		[1] = "绿色装备 X",
		[2] = "蓝色装备 X",
		[3] = "紫色装备 X",
		[4] = "金色装备 X",
 	}
	for i = 0,4 do
		if offlineData:getEquipCountByColor(i) and offlineData:getEquipCountByColor(i) ~= 0 then
			equipCountStr =string.format("{e=[%s%d],c=[%d]}",equipStr[i],offlineData:getEquipCountByColor(i),i+1)
			local element = self:msgParser(string.format("获得:%s",equipCountStr),cc.c3b(255,255,255))
			table.insert(self.offlineElementList,element)
		end
	end
	if offlineData:getEquip_SellNumber() then
		equipSellNumberStr =  string.format("{o=[%d]}",offlineData:getEquip_SellNumber())
		local element = self:msgParser(string.format("其中，卖出装备:%s",equipSellNumberStr),cc.c3b(255,255,255))
		table.insert(self.offlineElementList,element)
	end
	if offlineData:getEquip_SellPrice() then
		equipSellPriceStr = string.format("{o=[%d]}",offlineData:getEquip_SellPrice())
		local element = self:msgParser(string.format("卖出得到金币:%s",equipSellPriceStr),cc.c3b(255,255,255))
		table.insert(self.offlineElementList,element)
	end
	local event = cc.EventCustom:new("Text_Set")
	cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
end


function BattleWordDataHandler:msgParser(msg,commonColor)
	self.richElementList = {}
	if not commonColor then
		commonColor = wd.battleColorTable["common"]
	end
	local startIndex,lastIndex,str,color,index,colorStr
	local parsedStr = msg
	self.tag = 1
	if type(parsedStr) == "string" then	
		local circleTime = 0
		while (string.find(parsedStr,"{") ~= nil)	
		do
			if circleTime > 30 then
				break
			end
			
			index= string.find(parsedStr,"{")
			local strType = string.sub(parsedStr,index+1,index+1)
			-- 自己
			if strType == "a" then
				startIndex,lastIndex,str = string.find(parsedStr,"{a=%[(.-)%]}")  
				color = wd.battleColorTable["myself"]
			-- 敌人
			elseif strType == "d" then
				startIndex,lastIndex,str = string.find(parsedStr,"{d=%[(.-)%]}")  
				color = wd.battleColorTable["enemy"]
			-- 类型
			elseif strType == "t" then
				startIndex,lastIndex,str = string.find(parsedStr,"{t=%[(.-)%]}")  
				color = wd.battleColorTable["type"]
			elseif strType == "v" then
			-- 数字
				startIndex,lastIndex,str,colorStr = string.find(parsedStr,"{v=%[(.-)%],c=%[(.-)%]}")  
				if colorStr == "MP" then
					color = wd.battleColorTable["MPvalue"]
				elseif colorStr == "AddHP" then
					color = wd.battleColorTable["type"]
				else
					color = wd.battleColorTable["value"]
				end
			elseif strType == "s" then
			-- 技能
				startIndex,lastIndex,str = string.find(parsedStr,"{s=%[(.-)%]}")  
				color = wd.battleColorTable["skill"]
			elseif strType == "i" then
			-- 物品
				startIndex,lastIndex,str = string.find(parsedStr,"{i=%[(.-)%]}")  
				color = wd.battleColorTable["item"]
			-- 装备
			elseif strType == "e" then
				startIndex,lastIndex,str,colorStr = string.find(parsedStr,"{e=%[(.-)%],c=%[(.-)%]}")  
				color = wd.colorTable[tonumber(colorStr)]
				--color = wd.battleColorTable["item"]
			-- offline
			elseif strType == "o" then
				startIndex,lastIndex,str = string.find(parsedStr,"{o=%[(.-)%]}")  
				color = wd.battleColorTable["offlne"]
			end
			if startIndex and lastIndex and str then
				self:parseStrAndSetRichElement(parsedStr,startIndex,lastIndex,str,color,commonColor)
				parsedStr = string.sub(parsedStr,lastIndex+1,-1)
			end
			circleTime = circleTime + 1
		end
		parsedStr = string.sub(parsedStr,1,-1) 
		local richElement = ccui.RichElementText:create(self.tag,commonColor,255,parsedStr,"Helvetica",self.fontSize)
		self.tag = self.tag+1
		table.insert(self.richElementList,richElement)
		
		return self.richElementList
	end
end

function BattleWordDataHandler:parseStrAndSetRichElement(parsedStr,startIndex,lastIndex,str,color,commonColor)
    if not color then
        color = wd.battleColorTable["common"]
    end
	parsedStr = string.sub(parsedStr,1,startIndex-1)
	local richElement = ccui.RichElementText:create(self.tag,commonColor,255,parsedStr,"Helvetica",self.fontSize)
	self.tag = self.tag+1
	table.insert(self.richElementList,richElement)
	richElement = ccui.RichElementText:create(self.tag,color,255,str,"Helvetica",self.fontSize)
	self.tag = self.tag+1
	table.insert(self.richElementList,richElement)
end

return BattleWordDataHandler