
local BossEliteLayer = class("BossEliteLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end


function BossEliteLayer.create()
    local layer = BossEliteLayer.new()
    layer:createLayerMenu()
    return layer
end

function BossEliteLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
	self.curPage = 1
	self.pagePos = {
		[1] = 0,
		[2] = 50,
		[3] = 100,
	}
	self.dataHandler = wd.bossHandler 
end

function BossEliteLayer:clear()
	self:removeFromParent()
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Fight_Boss")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Remove_Tips")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Buy_Boss_Number")
end

function BossEliteLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/boss/BossEliteScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)
    ccui.Helper:doLayout(node)
	
    local backBtn = ccui.Helper:seekWidgetByName(node,"Close_Button")
	backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				local event = cc.EventCustom:new("Check_New_Tip")
				cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
				self:clear()
            end
        end
    )
	
	local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Main_Panel"), "ccui.Widget")
	
	local numberLabel = tolua.cast(mainPanel:getChildByName("Number_Label"), "ccui.Text")
	numberLabel:setString(wd.GlobalData:getInstance():getRoleData():getBossChallengeNum())
	
	local hadFightBossId = wd.GlobalData:getInstance():getRoleData():getBossId()
	
	if hadFightBossId+1 > 8 and hadFightBossId+1 <= 16 then
		self.curPage = 2
	elseif hadFightBossId+1 > 16 then
		self.curPage = 3
	else
		self.curPage = 1
	end
	local bossScroll = tolua.cast(mainPanel:getChildByName("Boss_ScrollView"), "ccui.ScrollView")
	local bossLayer = {}
	
	bossLayer[1] = tolua.cast(cc.CSLoader:createNode("ui/boss/BossLayer.csb"), "ccui.Widget")
	bossLayer[2] = tolua.cast(cc.CSLoader:createNode("ui/boss/BossLayer.csb"), "ccui.Widget")
	bossLayer[3] = tolua.cast(cc.CSLoader:createNode("ui/boss/BossLayer.csb"), "ccui.Widget")
	local size
	for j = 1,3 do
		local bossPanel = tolua.cast(ccui.Helper:seekWidgetByName(bossLayer[j],"Boss_Panel"), "ccui.Widget")
		bossPanel:setContentSize(bossScroll:getContentSize())
		ccui.Helper:doLayout(bossPanel)
		bossPanel:setSwallowTouches(false)
		size = bossPanel:getContentSize()
		for i = 1,8 do
			local openFlag = false
			local tag = (j-1)*8+i
			local bossItem = wd.GlobalData:getInstance():getBossItemInXml(tag-1)
			local name = string.format("Boss_%d",i)
			local bossNode = tolua.cast(bossPanel:getChildByName(name), "ccui.Widget")
			local bossBox =  tolua.cast(bossNode:getChildByName("Boss_Box"), "ccui.Widget")
			bossBox:setSwallowTouches(false)
			local bossDisable = tolua.cast(bossBox:getChildByName("Boss_Disable"), "cc.Sprite")
			bossDisable:setSpriteFrame(string.format("boss_%d_disable.png",tag))
			local bossNormal = tolua.cast(bossBox:getChildByName("Boss_Normal"), "cc.Sprite")
			bossNormal:setSpriteFrame(string.format("boss_%d_normal.png",tag))
			local bossLock = tolua.cast(bossBox:getChildByName("Boss_Lock"), "cc.Sprite")
			local arrowDisable,arrowNormal
			if i> 1 then
				arrowDisable = tolua.cast(bossPanel:getChildByName(string.format("Arrow_Disable_%d",i)), "cc.Sprite")
				arrowNormal = tolua.cast(bossPanel:getChildByName(string.format("Arrow_Normal_%d",i)), "cc.Sprite")
			end
			local bossBtn = tolua.cast(bossBox:getChildByName("Boss_Button"), "ccui.Button")
			bossBtn:addTouchEventListener(
				function(sender,eventType)
					if eventType == ccui.TouchEventType.ended then
						if tag <= hadFightBossId+1 then
							if wd.GlobalData:getInstance():getRoleData():getBossChallengeNum() > 0 then
								local itemList = self.dataHandler:getItemList(bossItem:getDropStr())
								local layerClass = require("src.game.boss.BossChallengeTips")
								local layer = layerClass.create()
								layer:createLayerMenu(tag,itemList)
								self:addChild(layer)
								self.bossName = bossItem:getName()
								self.bossLevel = bossItem:getLevel()
							else
								wd.showRichTips(4,"挑战次数不足")
							end
						else
							wd.showRichTips(4,string.format("请先战胜第%d个Boss",hadFightBossId+1))
						end
					end
				end
			)
			if tag <= hadFightBossId+1 then	
				openFlag = true
			end
			bossBtn:setSwallowTouches(false)
			local rankLable =  tolua.cast(bossBox:getChildByName("Rank_Label"), "ccui.Text")
			rankLable:setString(tag)
			local nameLabel = tolua.cast(bossBox:getChildByName("Name_Label"), "ccui.Text")
			nameLabel:setString(bossItem:getName())
			local levelLabel = tolua.cast(bossBox:getChildByName("Level_Label"), "ccui.TextBMFont")
			levelLabel:setString(string.format("Lv %d",bossItem:getLevel()))
			
			
			bossNormal:setVisible(openFlag)
			bossDisable:setVisible(not openFlag)
			if arrowNormal and arrowDisable then
				arrowNormal:setVisible(openFlag)
				arrowDisable:setVisible(not openFlag)
			end
			bossLock:setVisible(not openFlag)
		end	
	end
	
	local addBtn =  tolua.cast(mainPanel:getChildByName("Add_Button"), "ccui.Button")
	addBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				local layerClass = require("src.game.family.Family_MessageBox_Layer")
				local msg = {}
				table.insert(msg,"是否花 ")
				table.insert(msg,string.format("{n=[%s]}",tostring(20)))
				table.insert(msg," 元宝购买 ")
				table.insert(msg,string.format("{n=[%s]}",tostring(1)))
				table.insert(msg," 次挑战次数")
				local function buyNumber()
					self.dataHandler:requestBuyBossChanllengeNumber()
				end
				self.tipsLayer = layerClass.create("boss_subtitle_buycount.png",msg,buyNumber)
				self:addChild(self.tipsLayer)
            end
        end
    )
	
	
	
	
	
	local totalLayer = ccui.Widget:create()
	totalLayer:setSwallowTouches(false)
	totalLayer:setAnchorPoint(cc.p(0,0))
	totalLayer:setContentSize(cc.size(bossScroll:getContentSize().width*3,size.height))
	totalLayer:addChild(bossLayer[1])
	totalLayer:addChild(bossLayer[2])
	totalLayer:addChild(bossLayer[3])
	local width = (bossScroll:getContentSize().width-size.width)/2
	bossLayer[1]:setPosition(width,0)
	bossLayer[2]:setPosition(bossScroll:getContentSize().width+width,0)
	bossLayer[3]:setPosition(bossScroll:getContentSize().width*2+width,0)
	
	bossScroll:setInnerContainerSize(totalLayer:getContentSize())
	bossScroll:setInertiaScrollEnabled(false)
	bossScroll:addChild(totalLayer)
	totalLayer:setPosition(0,0)
	local function scrollTurnPage(page)
		bossScroll:scrollToPercentHorizontal(self.pagePos[page],0.7,true)
	end
	bossScroll:addTouchEventListener(
        function(sender,eventType)
			local layer = sender:getInnerContainer()
            if eventType == ccui.TouchEventType.began then
				self.beganX = layer:getPosition()
			elseif eventType == ccui.TouchEventType.ended then
				self.endX = layer:getPosition()
				if self.endX > 0 or self.endX < -sender:getContentSize().width*2 then
					return
				end
				if math.abs(self.beganX - self.endX) > 60 then
					if self.endX > self.beganX and self.curPage ~= 1 then
						self.curPage = self.curPage - 1
					elseif self.endX < self.beganX and self.curPage ~= 3 then
						self.curPage = self.curPage + 1
					end
					
				end
				scrollTurnPage(self.curPage)
            end
			
        end
    )
	bossScroll:scrollToPercentHorizontal(self.pagePos[self.curPage],0.1,false)
	
	local function onFightBoss(EventCustom)
		self:getParent():setBossFight(true,self.bossName,self.bossLevel)
		self:clear()
	end
	local listener = cc.EventListenerCustom:create("Fight_Boss", onFightBoss)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local function onRemoveTips(EventCustom)
		if self.tipsLayer then
			self.tipsLayer = nil
		end
	end
	local listener = cc.EventListenerCustom:create("Remove_Tips", onRemoveTips)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local function onBuyBossNumber(EventCustom)
		if self.tipsLayer then
			wd.showRichTips(4,"购买成功")
			numberLabel:setString(wd.GlobalData:getInstance():getRoleData():getBossChallengeNum())
			self.tipsLayer:removeFromParent()
			self.tipsLayer = nil
		end
	end
	local listener = cc.EventListenerCustom:create("Buy_Boss_Number", onBuyBossNumber)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
end

return BossEliteLayer

