
local VipLayer = class("VipLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function VipLayer.create()
    local layer = VipLayer.new()
    layer:createLayerMenu()
    return layer
end

function VipLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
    self.mainPanel = nil
    self.privilegeList = nil
    self.selectBtn = nil
    self.level = nil
    wd.TranscodingSend:getVipItemList()
end

function VipLayer:registerEventListener()

    local function getCallback(EventCustom)
        local getData = wd.GlobalData:getInstance():getMessage("Get_Item")
        if getData:len() >= 5 then

            local layerClass = require("src.game.package.ToolsGetLayer")
            local layer = layerClass.create()
            layer:createLayerMenu(getData)
            self:getParent():addChild(layer)
            
            if self.level ~= nil then
                self:setGift(self.level)
				self:refreshList()
            end
        end
    end

    local listener = cc.EventListenerCustom:create("Get_Item", getCallback)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
end

function VipLayer:unregisterEventListener()
    cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Vip")
    cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Item")
end

function VipLayer:setData()

    local levelLabel = tolua.cast(ccui.Helper:seekWidgetByName(self.mainPanel,"VipLevel_Label"), "ccui.TextAtlas")
    
    local levelLabelNow = tolua.cast(ccui.Helper:seekWidgetByName(self.mainPanel,"VipLevel_Label_Now"), "ccui.TextAtlas")

    local expPanel = tolua.cast(ccui.Helper:seekWidgetByName(self.mainPanel,"Panel_Exp"), "ccui.Widget")

    local needexpLabel = tolua.cast(ccui.Helper:seekWidgetByName(expPanel,"NeedExp_Label"), "ccui.Text")

    local needexpTitle = tolua.cast(ccui.Helper:seekWidgetByName(expPanel,"NeedExp_Title"), "ccui.Text")

    local gemTitle = tolua.cast(ccui.Helper:seekWidgetByName(expPanel,"Gem_Title"), "ccui.Text")

    local expBar = tolua.cast(ccui.Helper:seekWidgetByName(expPanel,"Exp_Progress"), "ccui.LoadingBar")

    local expLabel = tolua.cast(ccui.Helper:seekWidgetByName(expPanel,"Exp_Label"), "ccui.Text")

    local function updataCallback()

        local level = wd.GlobalData:getInstance():getRoleVip()

        levelLabel:setString(wd.GlobalData:getInstance():getRoleVip())

        levelLabelNow:setString(wd.GlobalData:getInstance():getRoleVip())

        -- gemLabel:setString(wd.GlobalData:getInstance():getRoleGem())

        local number = wd.GlobalData:getInstance():getVipXmlCount()

        local exp = wd.GlobalData:getInstance():getRoleVipExp()
        local expMax = 999999
        
        if level < number then
            level = level + 1
        end
        
        local item = wd.GlobalData:getInstance():getVipXmlData(level)
        if item ~= nil then
            expMax = item:getMaxExp()
        end

        if level >= number-1 then
            gemTitle:setString(string.format("VIP已达最高等级"))
            needexpTitle:setString("")
            needexpLabel:setString("")
        else
            needexpTitle:setString("VIP"..level)
            needexpLabel:setString(expMax - exp)
        end

        expLabel:setString(string.format("%d/%d", exp, expMax))

        if exp > expMax then   
            exp = expMax
        end

        expBar:setPercent(exp/expMax*100)
        
        self:initList()

        self:setItem(self.level)
        
    end

    local listener = cc.EventListenerCustom:create("Update_Vip", updataCallback)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);

    --updataCallback()
end

function VipLayer:setGift(level)

    local item = wd.GlobalData:getInstance():getVipXmlData(level)

    if item == nil then
        return
    end

    local giftPanel = tolua.cast(ccui.Helper:seekWidgetByName(self.mainPanel,"Panel_Gift"), "ccui.Widget")

    local levelLabel = tolua.cast(ccui.Helper:seekWidgetByName(giftPanel,"VipLevel_SubLabel"), "ccui.TextAtlas")
    levelLabel:setString(level)

    local rewardList = tolua.cast(ccui.Helper:seekWidgetByName(self.mainPanel,"Get_ListView"), "ccui.ListView")
    rewardList:removeAllItems()
    require("src.game.package.SetupTools"):create(rewardList,item:getReward())

    local prevValueLabel = tolua.cast(giftPanel:getChildByName("PrevValue_Label"), "ccui.Text")
    prevValueLabel:setString(string.format("原价: 元宝%d",item:getPrice()))
    
    local curValueLabel = tolua.cast(giftPanel:getChildByName("CurValue_Label"), "ccui.Text")
    curValueLabel:setString(string.format("折扣价: 元宝%d",item:getDiscountPrice()))

    local buyLabel = tolua.cast(giftPanel:getChildByName("Buy_Title"), "ccui.Text")
	local hadBuySprite = tolua.cast(giftPanel:getChildByName("HadBuy_Sprite"), "cc.Sprite")
    if wd.GlobalData:getInstance():getRoleVip() >= level then
        if item:getIsBuy() then
            --buyLabel:setString("已购买")
			buyLabel:setVisible(false)
			hadBuySprite:setVisible(true)
        else
			buyLabel:setVisible(true)
			hadBuySprite:setVisible(false)
            buyLabel:setString("仅购买一次")
        end
    else
		buyLabel:setVisible(true)
		hadBuySprite:setVisible(false)
        buyLabel:setString(string.format("vip等级未达到vip%d",level))
    end
    
    local buyBtn = tolua.cast(ccui.Helper:seekWidgetByName(giftPanel,"Buy_Button"), "ccui.Widget")
    buyBtn:setPressedActionEnabled(true)
    buyBtn:setTag(item:getDiscountPrice())
    buyBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                if item:getIsBuy() then
                    wd.showRichTips(4,"该礼包已购买")
                    return
                end
                local roleVipLevel = wd.GlobalData:getInstance():getRoleVip()
                if roleVipLevel >= level then
                    if item ~= nil then
                        wd.TranscodingSend:buyVipItem(level)
                    end

                else
                    wd.showRichTips(4,string.format("vip等级未达到vip%d",level))
                end
            end
        end
    )
    
    -- local contentsBtn = tolua.cast(ccui.Helper:seekWidgetByName(giftPanel,"Contents_Button"), "ccui.Widget")
    -- contentsBtn:setTag(item:getItemId())
    -- contentsBtn:addTouchEventListener(
    --     function(sender,eventType)
    --         if eventType == ccui.TouchEventType.ended then
    --             local layerClass = require("src.game.package.ToolsGetPreviewLayer")
    --             local layer = layerClass.create()
    --             layer:createLayerMenu(sender:getTag())
    --             self:addChild(layer)
    --         end
    --     end
    -- )

end

function VipLayer:setItem(level)
    
    local addUp = 0
    for n = 0,level do
        addUp = addUp + wd.GlobalData:getInstance():getVipXmlData(n):getMaxExp()
    end
    
    self.addUp:setString(addUp)
    
    self.vipLabelTitle:setString(level)
    self.vipLabelGet:setString(level)
    
    self.privilegeList:removeAllChildren()
    
    local item = wd.GlobalData:getInstance():getVipXmlData(level)
    
    if item == nil then
        return
    end
    
    local number = item:getPrivilegeCount()
    
    local layoutWidth = 370
    local layoutHeight = 40
    
    for i=0, number-1 do
        local privilege = item:getPrivilegeAttr(i)
        if privilege == nil or privilege == "" then
            break
        end
        
        local layout = ccui.Layout:create()
        layout:setContentSize(layoutWidth,layoutHeight)
        
        local pattern = cc.Sprite:create()
        pattern:setSpriteFrame("ui/commonality/vip_list_pattern.png")
        pattern:setAnchorPoint(cc.p(0,0.5))
        pattern:setPositionY(layoutHeight/2)
        layout:addChild(pattern)
        
        local label = ccui.Text:create()
        label:setAnchorPoint(cc.p(0,0.5))
        label:setString(privilege)
        label:setFontSize(20)
        label:setPosition(pattern:getContentSize().width + 5,layoutHeight/2)
        layout:addChild(label)
        
        local line = cc.Sprite:create()
        line:setSpriteFrame("charge_line.png")
        line:setAnchorPoint(cc.p(0.5,0))
        line:setPositionX(layoutWidth/2)
        layout:addChild(line)
        
        

        self.privilegeList:pushBackCustomItem(layout)
    end
    
    self:setGift(level)
        
end


function VipLayer:refreshList()
	-- self:initList()
end
function VipLayer:initList()
    if self.init then
        return
    else
        self.init = true
    end

    local number = wd.GlobalData:getInstance():getVipXmlCount()
    
    local size = wd.GlobalData:getInstance():getVipXmlCount()
           
    local function leftBtnCallback(sender,eventType)
        if eventType == ccui.TouchEventType.ended then
            self.level = self.level - 1
            
            self.rightBtn:setVisible(true)

            if self.level <= 0 then
                self.leftBtn:setVisible(false)
            end
            
            self:setItem(self.level)
        end
    end
    
    local function rightBtnCallback(sender,eventType)
        if eventType == ccui.TouchEventType.ended then
            self.level = self.level + 1
            
            if self.level + 1 >= size then
                self.rightBtn:setVisible(false)
            end
            
            self.leftBtn:setVisible(true)

            self:setItem(self.level)
        end
    end
    
    if self.level <= 0 then
        self.leftBtn:setVisible(false)
    elseif self.level + 1 >= size then
        self.rightBtn:setVisible(false)
    end
    
    local moveByLeft = cc.MoveBy:create(1,cc.p(-15,0))
    local moveByRight = cc.MoveBy:create(1.5,cc.p(15,0))
    local sequence = cc.Sequence:create(moveByLeft,moveByRight)
    self.leftBtn:runAction(cc.RepeatForever:create(sequence))
    
    moveByLeft = cc.MoveBy:create(1,cc.p(15,0))
    moveByRight = cc.MoveBy:create(1.5,cc.p(-15,0))
    sequence = cc.Sequence:create(moveByLeft,moveByRight)
    self.rightBtn:runAction(cc.RepeatForever:create(sequence))
    
    self.leftBtn:setPressedActionEnabled(true)
    self.rightBtn:setPressedActionEnabled(true)
    self.leftBtn:addTouchEventListener(leftBtnCallback)
    self.rightBtn:addTouchEventListener(rightBtnCallback)
    
end


function VipLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/charge/VipScene.csb"), "ccui.Widget")
    self:addChild(node)
    self.mainPanel = node

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)

    local backBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Back_Button"), "ccui.Widget")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				local event = cc.EventCustom:new("Check_New_Tip")
				cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
                self:unregisterEventListener()
                self:removeFromParent()
            end
        end
    )

    local function chargeCallback(sender,eventType)
        if eventType == ccui.TouchEventType.ended then
            self:unregisterEventListener()
            local layerClass = require("src.game.charge.ChargeLayer")
            local layer = layerClass.create()
            self:getParent():addChild(layer)
            self:removeFromParent()
        end
    end

    -- local chargeBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Charge_Button"), "ccui.Button")
    -- chargeBtn:addTouchEventListener(chargeCallback)
    local gochargeBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"GoCharge_Button"), "ccui.Button")
    gochargeBtn:setPressedActionEnabled(true)
    gochargeBtn:addTouchEventListener(chargeCallback)

    self.privilegeList = tolua.cast(ccui.Helper:seekWidgetByName(node,"Privilege_ListView"), "ccui.ListView")
    self.leftBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Button_Left"), "ccui.Button")
    self.rightBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Button_Right"), "ccui.Button")

    self.vipLabelTitle = tolua.cast(ccui.Helper:seekWidgetByName(node,"VipLevel_Label_title"), "ccui.TextAtlas")
    self.vipLabelGet = tolua.cast(ccui.Helper:seekWidgetByName(node,"VipLevel_Label_get"), "ccui.TextAtlas")
    self.addUp = tolua.cast(ccui.Helper:seekWidgetByName(node,"add_up"), "ccui.Text")

    self.level = wd.GlobalData:getInstance():getRoleVip()
    
    self:setData()
    
    self:registerEventListener()

end


return VipLayer