
local GiftAchieveLayer = class("GiftAchieveLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end


function GiftAchieveLayer.create()
    local layer = GiftAchieveLayer.new()
    layer:createLayerMenu()
    return layer
end

function GiftAchieveLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
	self.dataHandler = wd.giftHandler 
	self.getBtnState = true
	self.getBtnStateTime = 0
	self.achieveState = {
		Unreach = 0,
		CanGet = 1,
		HadGet = 2,
	}
	self.isShowEffect = false
end

function GiftAchieveLayer:clear()
	self:removeFromParent()
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_AchieveList")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Award")
end

function GiftAchieveLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/gift/AchieveScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)
    ccui.Helper:doLayout(node)
	
    local backBtn = ccui.Helper:seekWidgetByName(node,"Close_Button")
	backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                if self.clippingLayer then
                    self.clippingLayer:removeFromParent()
                    self.clippingLayer = nil
                end
				self:clear()
            end
        end
    )
	
	local purchaseBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Purchase_Button"), "ccui.Button")
    purchaseBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				self.dataHandler:requestOpenDiscountShop()
				local layerClass = require("src.game.gift.GiftPurchaseLayer")
                local layer = layerClass.create()
                self:getParent():addChild(layer)
				self:clear()
            end
        end
    )
	
	
	local achieveListView = tolua.cast(ccui.Helper:seekWidgetByName(node,"Achieve_List"), "ccui.ListView")
	local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Main"), "ccui.Widget")
	self.getAwardEffect = tolua.cast(mainPanel:getChildByName("Get_Award_Effect"), "cc.Sprite")
	
	local function updateCallBack(EventCustom)
		self.getBtnState = true
		achieveListView:removeAllItems()
		local achieveList = self.dataHandler:getShowAchieveList()
		for i,v in ipairs(achieveList) do
			local widget = ccui.Widget:create()
			local achieveNode =  tolua.cast(cc.CSLoader:createNode("ui/gift/AchieveNode.csb"),"ccui.Widget")
			local titleLabel =  tolua.cast(achieveNode:getChildByName("Title_Label"), "ccui.Text")
			titleLabel:setString(v.title)
			local getButton = tolua.cast(achieveNode:getChildByName("Get_Button"),"ccui.Button")
			local cannotGetButton = tolua.cast(achieveNode:getChildByName("CannotGet_Button"),"ccui.Button")
			getButton:setPressedActionEnabled(true)
			cannotGetButton:setPressedActionEnabled(true)
			if v.state == self.achieveState.Unreach or v.state == self.achieveState.HadGet then
				getButton:setVisible(false)
				cannotGetButton:setVisible(true)
			else
				getButton:setVisible(true)
				cannotGetButton:setVisible(false)
			end
			getButton:addTouchEventListener(
				function(sender,eventType)
					if eventType == ccui.TouchEventType.ended then
                        if self.clippingLayer then
                            self.clippingLayer:removeFromParent()
                            self.clippingLayer = nil
                            ------------------------------新手引导----------------------------
                            local clippingLayer = require("src.game.guidance.GuidanceLayer"):create()
                            if clippingLayer then
                                clippingLayer:setGuidance(backBtn,30,50,115,115,nil,true)
                                local msgTable = {}
                                local msg = {}
                                table.insert(msg,"{r=[勇士]}")
                                table.insert(msg,"，新手介绍已结束，赶紧踏上杀敌爆装的激情世界吧！")
                                table.insert(msgTable,msg)
                                clippingLayer:setMsg(msgTable)
                                self.clippingLayer = clippingLayer
                                self:addChild(clippingLayer)
                                wd.GlobalData:getInstance():setCreateRoleFlag(false)
                            end
                            ------------------------------------------------------------------
                        end
						if os.time()-self.getBtnStateTime > 3 then
							self.getBtnState = true
						end
						if self.getBtnState then
							self.dataHandler:requestGetFinishAward(tonumber(v.id))
							self.getBtnState = false
							self.getBtnStateTime = os.time()
						end
					end
				end
			)
			
			cannotGetButton:addTouchEventListener(
				function(sender,eventType)
					if eventType == ccui.TouchEventType.ended then
						if self.getBtnState then
							if v.state == self.achieveState.Unreach then
								wd.showRichTips(4,"还未达成，要努力哦亲")
							elseif v.state == self.achieveState.HadGet then
								wd.showRichTips(4,"该类成就已全部领取")
							end
						end
					end
				end
			)
			
			local btnTitle = tolua.cast(cannotGetButton:getChildByName("Button_Title"), "ccui.Text")
			btnTitle:setString(v.stateStr)
			
			local itemListView = tolua.cast(achieveNode:getChildByName("Item_ListView"), "ccui.ListView")
			itemListView:setSwallowTouches(false)
			for index,itemInfo in ipairs(v.awardList) do
				local btn = ccui.Button:create("role_equip_button.png", "role_equip_button.png", "", ccui.TextureResType.plistType)
				btn:setAnchorPoint(cc.p(0,0))
				local itemNode = tolua.cast(cc.CSLoader:createNode("ui/gift/ItemNode.csb"),"ccui.Widget")
				btn:addChild(itemNode)
				local image = tolua.cast(itemNode:getChildByName("Tools_Sprite"), "cc.Sprite")
				image:setSpriteFrame(string.format("%d.png",itemInfo.itemType))
				local color = tolua.cast(itemNode:getChildByName("Color_Sprite"), "cc.Sprite")
				local colorStr
				if tonumber(itemInfo.itemType) == wd.rewardItemType.MAIL_MONEY then 
					colorStr = string.format("%02d.png",4)
				elseif tonumber(itemInfo.itemType) == wd.rewardItemType.MAIL_GEM then 
					colorStr = string.format("%02d.png",5)
				else
					local item = wd.GlobalData:getInstance():getToolsItemInXml(tonumber(itemInfo.itemType))
					colorStr = string.format("%02d.png",item:getQuality())
					btn:addTouchEventListener(
						function(sender,eventType)
							if eventType == ccui.TouchEventType.ended then
								local layerClass =  require("game.package.ToolsTipsLayer")
								local layer = layerClass.create()
								layer:createLayerMenu(tonumber(itemInfo.itemType),true)
								self:addChild(layer)
							end
						end
					)
					if item:getQuality() == 5 then
						wd.itemEffect(image)
					end
				end
				color:setSpriteFrame(colorStr)
				
				local quantityLabel = tolua.cast(itemNode:getChildByName("Number_Label"), "ccui.Text")
				quantityLabel:setVisible(true)
				quantityLabel:setString(string.format("%d", itemInfo.itemCount))
				itemListView:pushBackCustomItem(btn)
			end
			
			local background =  tolua.cast(achieveNode:getChildByName("Background_Sprite"), "cc.Sprite")
			widget:setContentSize(background:getContentSize())
			widget:setAnchorPoint(cc.p(0,0))
			widget:setTag(i)
			widget:addChild(achieveNode)
			achieveNode:setPosition(cc.p(0,0))
			achieveListView:pushBackCustomItem(widget) 
            if i == 2 and not self.guidance then
                ------------------------------新手引导----------------------------
                self.guidance = true
                local clippingLayer = require("src.game.guidance.GuidanceLayer"):create()
                if clippingLayer then
                    local position = widget:convertToWorldSpace(cc.p(getButton:getPositionX(),getButton:getPositionX()))
                    position.y = achieveListView:getPositionY() + getButton:getPositionY()*2.5
                    clippingLayer:setGuidance(getButton,30,50,115,115,position)
                    local msgTable = {}
                    local msg = {}
                    table.insert(msg,"哇，")
                    table.insert(msg,"{r=[元宝]}")
                    table.insert(msg,"还真不少，咱们快领取！")
                    table.insert(msgTable,msg)
                    clippingLayer:setMsg(msgTable)
                    self.clippingLayer = clippingLayer
                    self:addChild(clippingLayer)
                end
                ------------------------------------------------------------------
            end
		end
		--[[if self.isShowEffect then
			self.isShowEffect = false
			self:effect()
		end--]]
	end
	
		
	local function getAwardCallBack(EventCustom)
		--wd.showSystemTips("领取成功")
		self.isShowEffect = true
		self.dataHandler:requestFinishAwardState()
		--self:effect()
	end
	
	local listener = cc.EventListenerCustom:create("Update_AchieveList", updateCallBack)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local listener = cc.EventListenerCustom:create("Get_Award", getAwardCallBack)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
end

function GiftAchieveLayer:effect()
    self.getAwardEffect:setVisible(true)
    
    local function delayCallBackFunc(sender)
        self.getAwardEffect:setVisible(false)
    end

    local delayCallBack = cc.CallFunc:create(delayCallBackFunc)

    local animation = cc.Animation:create()
    for i = 1, 8 do
        animation:addSpriteFrame(cc.SpriteFrameCache:getInstance():getSpriteFrame(string.format("getAward_%02d.png", i)))
    end

    animation:setDelayPerUnit(0.1)
    animation:setLoops(1)
    local action = cc.Animate:create(animation)
    local sequenceAction = cc.Sequence:create(action, delayCallBack)

    self.getAwardEffect:runAction(sequenceAction)
   
end

return GiftAchieveLayer
