
local GiftDataHandler = class("GiftDataHandler")

local cclog = function(...)
    print(string.format(...))
end


function GiftDataHandler:ctor()
	self:initData()
	self:registerEventListener()
end

function GiftDataHandler:getInstance()
	if not self.instance then
		self.instance = GiftDataHandler.new()
	end
	return self.instance
end

function GiftDataHandler:destroyInstance()
    if self.instance then
        cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_FinishAwardState")
        cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_FinishAward")
        cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Open_DiscountShop")
        self.instance = nil
    end
end

function GiftDataHandler:initData()
	self.achieveList = {}
	self.discountItemList = {}
	self.achieveType = {
		VIP = 1,
		Level = 2,
		FightPower = 3,
		Tripod = 4,
		Arena = 5,
		Login = 6,
        boss = 7,
	}
    
	self.achieveDes = {
		[1] = "VIP等级达到%d级",
		[2] = "玩家等级达到%d级",
		[3] = "战力达到%d",
		[4] = "龙鼎等级达到%d级",
		[5] = "竞技排名达到%d",
		[6] = "登陆奖励（第%d天)",
        [7] = "战胜%sboss",
	}
	
	self.getTypeStr = {
		[0] = "未达成",
		[1] = "",
		[2] = "已领取",
	}
end

function GiftDataHandler:requestFinishAwardState()
	wd.TranscodingSend:getFinishAwardState()
end

function GiftDataHandler:requestGetFinishAward(awardId)
	wd.TranscodingSend:getFinishAward(awardId)
end

function GiftDataHandler:requestOpenDiscountShop()
	wd.TranscodingSend:openDiscountShop()
end

function GiftDataHandler:requestBuyDiscountItem(itemId)
	wd.TranscodingSend:buyDiscountItem(itemId)
end

function GiftDataHandler:getShowAchieveList()
	return self.achieveList
end

function GiftDataHandler:getDiscountItemList()
	return self.discountItemList
end

function GiftDataHandler:parseAwardStr(awardStr)
	local awardList = {}
	local itemType,itemCount,startIndex,endIndex
	local str = awardStr
	while(str ~= "")
	do
		local item = {}
		startIndex,endIndex,item.itemType,item.itemCount = string.find(str,"(%d+)|(%d+)")
		table.insert(awardList,item)
		str = string.sub(str,endIndex+2,-1)
	end
	return awardList
end

function GiftDataHandler:registerEventListener()
	
	-- 从服务器接收技能列表回调
	local function getStateCallBack(EventCustom)
        local function getNameByCondiction(type,condiction)
            if type == 7 then
                return wd.GlobalData:getInstance():getMapName(condiction - 1)
            else
                return condiction
            end 
        end
        
		self.achieveList = {}
		local showAchieveCount = wd.GlobalData:getInstance():getShowAchieveItemCount()
		for i = 0 ,showAchieveCount-1 do
			local achieveInfo = {}
			local achieve = wd.GlobalData:getInstance():getShowAchieveItem(i)
			if achieve then
				achieveInfo.id = achieve:getAchieveId()
				achieveInfo.type = achieve:getAchieveType()
				if achieveInfo.id ~= 0 then
					achieveInfo.state = achieve:getAchieveState()
					achieveInfo.stateStr = self.getTypeStr[achieve:getAchieveState()]
					local condiction = achieve:getAchieveCondiction()
					achieveInfo.title = string.format(self.achieveDes[achieveInfo.type],getNameByCondiction(achieveInfo.type,condiction))
					local awardStr = achieve:getAchieveAward()
					achieveInfo.awardList = self:parseAwardStr(awardStr)
				else
					local lastAchieve = wd.GlobalData:getInstance():getLastAchieveItemInXmlByType(achieveInfo.type)
					achieveInfo.state = 2
					achieveInfo.stateStr = self.getTypeStr[2]
					local condiction = lastAchieve:getAchieveCondiction()
					achieveInfo.title = string.format(self.achieveDes[achieveInfo.type],getNameByCondiction(achieveInfo.type,condiction))
					local awardStr = lastAchieve:getAchieveAward()
					achieveInfo.awardList = self:parseAwardStr(awardStr)
				end
				table.insert(self.achieveList,achieveInfo)
			end
		end
		local event = cc.EventCustom:new("Update_AchieveList")
		cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
	end
	
	local function onGetFinishAward(EventCustom)
		local awardStr = wd.GlobalData:getInstance():getAchieveAward()
		local awardList = self:parseAwardStr(awardStr)
		local getData,itemInfo
		for i,v in ipairs(awardList) do
			v.itemType = tonumber(v.itemType)
			v.itemCount = tonumber(v.itemCount)	
			if v.itemType == wd.rewardItemType.MAIL_GEM or v.itemType == wd.rewardItemType.MAIL_MONEY then
				wd.GlobalData:getInstance():addMoneyToRole(v.itemType,v.itemCount)
				local event = cc.EventCustom:new("Update_Main")
				cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
			else
				wd.GlobalData:getInstance():addItem(v.itemType,v.itemCount)
			end
			if v.itemType ~= 1 and v.itemType ~= 2 then
				getData = string.format("1#%d|%d",v.itemType,v.itemCount)
			else
				getData = string.format("4#%d|%d",v.itemType,v.itemCount)
			end
			itemInfo = wd.getItemInfo(getData)
			if itemInfo~= nil and itemInfo.name ~= nil and itemInfo.color ~= nil and itemInfo.count ~= nil then
				local msg = {}
				table.insert(msg,"获得")
				table.insert(msg,string.format("{t=[%s],c=[%d]}",itemInfo.name,itemInfo.color))
				table.insert(msg,string.format("*%d",itemInfo.count))
				wd.showRichTips(wd.tipsType.Get,msg)
			end
		end
		local event = cc.EventCustom:new("Get_Award")
		cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
	end

	local function onOpenDiscountShop(EventCustom)
		self.discountItemList = {}
		local showDiscountCount = wd.GlobalData:getInstance():getDiscountShowListCount()
		for i = 0,showDiscountCount-1 do
			local discountItemInfo = {}
			local discountItem = wd.GlobalData:getInstance():getDiscountShowItem(i)
			discountItemInfo.id = discountItem:getDiscountId()
			discountItemInfo.title = discountItem:getName()
			discountItemInfo.number = discountItem:getLimitNumber() - discountItem:getHadBuyNum()
			discountItemInfo.price = discountItem:getPrice()
			discountItemInfo.discountPrice = discountItem:getDiscountPrice() 
			discountItemInfo.item = wd.GlobalData:getInstance():getToolsItemInXml(discountItem:getItemId())
			table.insert(self.discountItemList,discountItemInfo)
		end
		local event = cc.EventCustom:new("Update_DiscountList")
		cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
	end
	
	local listenerGetState = cc.EventListenerCustom:create("Get_FinishAwardState", getStateCallBack)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listenerGetState, 1)
	
	local listenerGetAward = cc.EventListenerCustom:create("Get_FinishAward", onGetFinishAward)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listenerGetAward, 1)
	
	local listenerOpenShop = cc.EventListenerCustom:create("Open_DiscountShop", onOpenDiscountShop)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listenerOpenShop, 1)
end

return GiftDataHandler
