local GuidanceLayer = class("GuidanceLayer",function()
    return cc.Layer:create()
end)

function GuidanceLayer:create()
    local layer 
    if wd.GlobalData:getInstance():getCreateRoleFlag() then
        layer = self:new()
    else
        layer = nil
    end
    return layer
end

function GuidanceLayer:ctor()
    self.winSize = cc.Director:getInstance():getWinSize()
end

function GuidanceLayer:setGuidance(btn,percentX,percentY,width,height,position,down)
    if not self.setUp then
        local node = tolua.cast(cc.CSLoader:createNode("ui/guidance/GuidanceNode.csb"), "ccui.Widget") 
        local clip = cc.LayerColor:create(cc.c4b(255,255,255,255),width,height)
        self.pointNode = cc.Sprite:create()
        self.pointNode:setSpriteFrame("ui/guidance/02.png")
        self.clip = clip
        
        local clippingNode = cc.ClippingNode:create(self.clip)
        local layer = cc.LayerColor:create(cc.c4b(0,0,0,70),self.winSize.width,self.winSize.height)
        clippingNode:addChild(layer)
        clippingNode:setInverted(true)
        clippingNode:setPosition(0,0)
        self:addChild(clippingNode)
        self.clippingNode = clippingNode
        
        local listenner = cc.EventListenerTouchOneByOne:create() 
        listenner:setSwallowTouches(true) 
        listenner:registerScriptHandler(function(touch, event)    
            local location = touch:getLocation()
            if location.x > self.clipPosition.x + width or location.x < self.clipPosition.x or location.y > self.clipPosition.y + height or location.y < self.clipPosition.y then
                return true  
            end
            return false  
        end, cc.Handler.EVENT_TOUCH_BEGAN ) 
        local eventDispatcher = self:getEventDispatcher()    
        eventDispatcher:addEventListenerWithSceneGraphPriority(listenner, self)   
        
        local flip = 1
        if down then
            flip = -1
        end
        
        local moveByUp = cc.MoveBy:create(0.6,cc.p(0,flip * 20))
        local moveByDown = cc.MoveBy:create(0.6,cc.p(0,flip * -20))
        local sequence = cc.Sequence:create(moveByUp,moveByDown)
        self.pointNode:runAction(cc.RepeatForever:create(sequence))
         
        self.node = node
        self:addChild(node)
          
        self.setUp = true
    end
    
    self.node:setPosition(self.winSize.width/100*percentX,self.winSize.height/100*percentY)

    local btnPosition = btn:convertToWorldSpace(cc.p(btn:getContentSize().width/2,btn:getContentSize().height/2))
    if position then
        btnPosition = position
    end
    self.clip:setPosition(btnPosition.x - width/2,btnPosition.y - height/2)
    
    self.clipPosition = self.clip:convertToWorldSpace(cc.p(0,0))
    if down then
        self.pointNode:setFlippedY(true)
        self.pointNode:setPosition(self.clipPosition.x + width/2,self.clipPosition.y - 39)
    else
        self.pointNode:setPosition(self.clipPosition.x + width/2,self.clipPosition.y + height + 39)
    end
    
    self:addChild(self.pointNode)

end

function GuidanceLayer:setMsg(msgTable)
    
    if not self.msgPanel then
        local msgPanel = tolua.cast(ccui.Helper:seekWidgetByName(self.node,"Msg_Panel"), "ccui.Widget")
        self.msgPanel = msgPanel
        
    else
        self.msgPanel:removeAllChildren() 
    end
    
    local size = self.msgPanel:getContentSize()
    
    local count = #msgTable
        
    local height = 0

    local layer = cc.Layer:create()
    
    for j,msg in ipairs(msgTable) do
        local richTextLabel = ccui.RichText:create()
        local startIndex,lastIndex,str,richElement
        for i,v in ipairs(msg) do
            if (string.find(v,"{r") ~= nil) then
                startIndex,lastIndex,str = string.find(v,"{r=%[(.-)%]}") 
                richElement = ccui.RichElementText:create(2,cc.c3b(255,0,0),255,str,"Helvetica",22)
            elseif (string.find(v,"{y") ~= nil) then
                startIndex,lastIndex,str = string.find(v,"{y=%[(.-)%]}") 
                richElement = ccui.RichElementText:create(2,cc.c3b(220,220,0),255,str,"Helvetica",22)
            elseif (string.find(v,"{g") ~= nil) then
                startIndex,lastIndex,str = string.find(v,"{g=%[(.-)%]}") 
                richElement = ccui.RichElementText:create(2,cc.c3b(0,220,0),255,str,"Helvetica",22)
            else
                richElement = ccui.RichElementText:create(2,cc.c3b(255,255,255),255,v,"Helvetica",22) 
            end
            richTextLabel:pushBackElement(richElement)
        end
        richTextLabel:formatText()
        local textSize = richTextLabel:getContentSize()
        if textSize.width > size.width-22 then
            self.upHeight = math.ceil(textSize.width / size.width) * textSize.height
            richTextLabel:setContentSize(size.width,self.upHeight)
        else
            self.upHeight = 22
        end
        
        richTextLabel:ignoreContentAdaptWithSize(false)
        richTextLabel:setPosition(size.width/2, height)
        richTextLabel:setAnchorPoint(cc.p(0.5,0.5))
        layer:addChild(richTextLabel)
        height = height - self.upHeight
    end
    
    height = math.abs(height)
    
    layer:setPosition(0, (size.height-height)/2 + height/2)
    self.msgPanel:addChild(layer)

end
  
-- function GuidanceLayer:clear()

--     self:removeFromParent()
-- end


return GuidanceLayer