
local MailDataHandler = class("MailDataHandler")

local cclog = function(...)
    print(string.format(...))
end


function MailDataHandler:ctor()
	self:initData()
	self:registerEventListener()
end

function MailDataHandler:getInstance()
	if not self.instance then
		self.instance = MailDataHandler.new()
	end
	return self.instance
end

function MailDataHandler:destroyInstance()
    if self.instance then
        cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Open_Mail")
        cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Mail")
        self.instance = nil
    end
end

function MailDataHandler:initData()
	self.mailCount = 0
	self.mailList = {}
	self.mailItemList = {}
end

function MailDataHandler:getMailList()
	return self.mailList
end

function MailDataHandler:getMailCount()
	return self.mailCount
end

function MailDataHandler:getMailByTag(tag)
	return self.mailList[tag]
end

function MailDataHandler:requestOpenMail()
    wd.TranscodingSend:openMail()
end

function MailDataHandler:setRevengeFightId(mailId)
	self.revengeFightId = mailId
end

function MailDataHandler:requestGetItemInMail(mailId)
	wd.TranscodingSend:getMail(mailId)
end

function MailDataHandler:requestRevengeFight()
	if self.revengeFightId then
		wd.TranscodingSend:revengeFight(self.revengeFightId)
	end
end

function MailDataHandler:getMailItemList(mailId,accessory_list)
	print(accessory_list)
	local str = accessory_list
	local itemList = {}
	local startIndex,endIndex,itemType,itemId,itemCount
	while(str ~= "")
	do
		local item = {}
		startIndex,endIndex,itemType,itemId,itemCount = string.find(str,"(%d+)|(%d+):(%d+)")
		item.itemType = tonumber(itemType)
		item.itemId = tonumber(itemId)
		item.itemCount = tonumber(itemCount)
		table.insert(itemList,item)
		str = string.sub(str,endIndex+2,-1)
	end
	self.mailItemList[mailId] = itemList
	return itemList
end

function MailDataHandler:registerEventListener()
	--从服务器接收技能列表回调

	local function openMailCallBack(EventCustom)
		self.mailList = {}
		local mailCount = wd.GlobalData:getInstance():getMailListSize()
		self.mailCount = mailCount
		for i = 0,mailCount-1 do
			local mail = wd.GlobalData:getInstance():getMail(i)
			table.insert(self.mailList,mail)
		end
		local event = cc.EventCustom:new("MailList_Set")
		cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
	end
	
	local function getReward()
		local mailId = wd.GlobalData:getInstance():getGetRewardMailId()
		if self.mailItemList[mailId] then
			for i,v  in ipairs(self.mailItemList[mailId]) do
				if tonumber(v.itemType) == wd.rewardItemType.MAIL_ITEM then
					wd.GlobalData:getInstance():addItem(v.itemId,v.itemCount)
				else
					--[[wd.GlobalData:getInstance():addMoneyToRole(v.itemId,v.itemCount)
					local event = cc.EventCustom:new("Update_Main")
					cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)--]]
				end
			end
		end
	end
	local listenerOpenMail = cc.EventListenerCustom:create("Open_Mail", openMailCallBack)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listenerOpenMail, 1)
	
	local listenerGetReward = cc.EventListenerCustom:create("Get_Mail", getReward)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listenerGetReward, 1)
	
end


return MailDataHandler
