

local MailLayer = class("MailLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end


function MailLayer.create()
    local layer = MailLayer.new()
    layer:createLayerMenu()
    return layer
end

function MailLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
	self.dataHandler = wd.mailHandler 
	self.tickScheduleList = {}
end

function MailLayer:clear()
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Mail")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("MailList_Set")
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Item_Msg")
	if self.tickScheduleList ~= {} then
		for i,v in ipairs(self.tickScheduleList) do
			if v ~= nil then
				cc.Director:getInstance():getScheduler():unscheduleScriptEntry(self.tickScheduleList[i])
				self.tickScheduleList[i] = nil
			end
		end
	end
    self:removeFromParent()
end

function MailLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/mail/MailScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)
   ccui.Helper:doLayout(node)


    local backBtn = ccui.Helper:seekWidgetByName(node,"Back_Button")
	backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				self:clear()
            end
        end
    )

	
	local mailListView = tolua.cast(ccui.Helper:seekWidgetByName(node,"Mail_ListView"), "ccui.ListView")
	
	local function setMailList()
		mailListView:removeAllItems()
		local mailList = self.dataHandler:getMailList()
		for index,mail in ipairs(mailList) do
			local mailNode,timeTitleStr,spriteStr,timeUpStr
			local elementTable = {}
			local widget = ccui.Widget:create()
			local canRevenge
			-- time
			local createTime = mail:getCreat_time()
			local deadlineTime = createTime + 24*3600
			local revengeNumberLabel
		-- arenaMail
			if mail:getMail_Type() == wd.MailType.ARENA_REVENGE then
				local curTime = os.time()
				local desTime = deadlineTime - curTime
				local equip = mail:getEquip()
				if equip:getServerId() >= 0 then
					if mail:getArenaRevengeType() == wd.ArenaRevengeType.Winner then
						mailNode = tolua.cast(cc.CSLoader:createNode("ui/mail/MailWinerNode.csb"),"ccui.Widget")
						elementTable[1] = ccui.RichElementText:create(1,cc.c3b(255,255,255),255,"您在竞技场中战胜 ","Helvetica",20)
						elementTable[2] = ccui.RichElementText:create(2,wd.battleColorTable["enemy"],255,mail:getSendName(),"Helvetica",20)
						elementTable[3] = ccui.RichElementText:create(3,cc.c3b(255,255,255),255," 天降鸿福获得 ","Helvetica",20)
						elementTable[4] = ccui.RichElementText:create(4,wd.colorTable[tonumber(equip:getColor())],255,equip:getName(),"Helvetica",20)
						
						timeTitleStr = "领取倒计时:"
						--infoStr = "(在时间内成功防守敌人复仇，便可领取装备)"
						timeUpStr= "可领取"
						local loseSprite = tolua.cast(mailNode:getChildByName("Lose_Sprite"), "cc.Sprite")
						if mail:getRead_state() == wd.MailReadState.REVENGEED then
							loseSprite:setVisible(true)
						else
							loseSprite:setVisible(false)
						end
						local getButton = tolua.cast(mailNode:getChildByName("Get_Button"), "ccui.Button")
						getButton:addTouchEventListener(
							function(sender,eventType)
								if eventType == ccui.TouchEventType.ended then
									if mail:getRead_state() ~= wd.MailReadState.REVENGEED then
										--领取
										self.dataHandler:requestGetItemInMail(mail:getMail_id())
									end
								end
							end
						)
					elseif mail:getArenaRevengeType() == wd.ArenaRevengeType.Loser then
						
						mailNode = tolua.cast(cc.CSLoader:createNode("ui/mail/MailLoserNode.csb"),"ccui.Widget")
						timeTitleStr = "复仇倒计时:"
						--infoStr = "(在时间内复仇成功，必定100%可追回装备)"
						timeUpStr = "复仇时间结束"
						local headSprite =  tolua.cast(mailNode:getChildByName("Head_Sprite"), "cc.Sprite")
						headSprite:setSpriteFrame(wd.getHeadImageName(mail:getSend_Occupation(), mail:getSend_Sex()))
						
						local job = tolua.cast(mailNode:getChildByName("Job_Title"), "cc.Sprite")
						job:setSpriteFrame(wd.getEquipTitleName(mail:getSend_Occupation()))
						
						local headButton = tolua.cast(mailNode:getChildByName("Head_Button"),"ccui.Button")
						headButton:setEnabled(true)
						headButton:addTouchEventListener(
							function(sender,eventType)
								if eventType == ccui.TouchEventType.ended then
									local layerClass = require("src.game.arena.PlayerLayer")
									local layer = layerClass.create()
									layer:createLayerMenu(wd.PlayerType.ENEMY)
									self:addChild(layer)
									wd.TranscodingSend:getPlayerData(mail:getSend_id())
								end
							end
						)
						
						local nameLabel =  tolua.cast(mailNode:getChildByName("Name_Label"), "ccui.Text")
						nameLabel:setString(mail:getSendName())
						
						local powerLabel =  tolua.cast(mailNode:getChildByName("Power_Label"), "ccui.Text")
						powerLabel:setString(mail:getSend_Power())
						
						
						
						elementTable[1] = ccui.RichElementText:create(1,cc.c3b(255,255,255),255,"您在竞技场中被 ","Helvetica",20)
						elementTable[2] = ccui.RichElementText:create(2,wd.battleColorTable["enemy"],255,mail:getSendName(),"Helvetica",20)
						elementTable[3] = ccui.RichElementText:create(3,cc.c3b(255,255,255),255," 所打败，掉落 ","Helvetica",20)
						elementTable[4] = ccui.RichElementText:create(4,wd.colorTable[tonumber(equip:getColor())],255,equip:getName(),"Helvetica",20)
						
						revengeNumberLabel =  tolua.cast(mailNode:getChildByName("RevengeNumber_Label"), "ccui.Text")
						local revengeButton = tolua.cast(mailNode:getChildByName("Get_Button"), "ccui.Button")
						revengeButton:addTouchEventListener(
							function(sender,eventType)
								if eventType == ccui.TouchEventType.ended then
									if mail:getRead_state() == wd.MailReadState.REVENGEED then
										--领取
										self.dataHandler:requestGetItemInMail(mail:getMail_id())
									else
										if (3-mail:getArenaRevengeNumber()) > 0 and canRevenge then
											self.dataHandler:setRevengeFightId(mail:getMail_id())
											self:getParent():setRevengeFight(true)
											self:clear()
										else
											if canRevenge then
												wd.showRichTips(4,"复仇次数不足")
											else
												wd.showRichTips(4,"复仇时间结束")
											end
										end
									end
								end
							end
						)
						local btnTitle =  tolua.cast(revengeButton:getChildByName("Get_Button_Title"), "cc.Sprite")
						if mail:getRead_state() == wd.MailReadState.REVENGEED then
							revengeNumberLabel:setString("复仇成功")
							btnTitle:setSpriteFrame("mail_get_subtitle.png")
						else
							local count = (3-mail:getArenaRevengeNumber()) > 0 and 3-mail:getArenaRevengeNumber() or 0
							revengeNumberLabel:setString(string.format("可复仇次数:%d",count))
							btnTitle:setSpriteFrame("mail_getback_subtitle.png")
						end
					end
				
					local equipSprite = tolua.cast(mailNode:getChildByName("Equip_Sprite"), "cc.Sprite")
					equipSprite:setSpriteFrame(string.format("%d.png",equip:getEquipId()%1000))
					local color = tolua.cast(mailNode:getChildByName("Color_Sprite"), "cc.Sprite")
					color:setSpriteFrame(string.format("%02d.png",equip:getColor()))
					local equipButton = tolua.cast(mailNode:getChildByName("Equip_Button"),"ccui.Button")
					equipButton:setEnabled(true)
					equipButton:addTouchEventListener(
						function(sender,eventType)
							if eventType == ccui.TouchEventType.ended then
								local layerClass = require("src.game.package.EquipTipsLayer")
								local layer = layerClass.create()
								layer:createLayerMenu(0, equip:getRegion(), 4, equip:getStrengthenLevel(),index-1)
								self:addChild(layer)
							end
						end
					)
						
					
					
					local timeLabel = tolua.cast(mailNode:getChildByName("Time_Label"), "ccui.Text")
					local h,m,s
					local function setTime()
						if desTime <= 0 then
							timeLabel:setString(timeUpStr)
							canRevenge = false
							if revengeNumberLabel then
								revengeNumberLabel:setString("复仇时间结束")
							end
						else
							canRevenge = true
							h = math.floor(desTime/3600)
							m = math.floor(math.abs(desTime-3600*h)/60)
							s = math.abs(desTime-h*3600-m*60)
							timeLabel:setString(string.format("%s %02d:%02d:%02d",timeTitleStr,h,m,s))
						end
					end
					setTime()
					local function timeTick()
						setTime()
						desTime = desTime - 1
					end
					local tickSchedule = cc.Director:getInstance():getScheduler():scheduleScriptFunc(timeTick, 1, false)
					table.insert(self.tickScheduleList,tickSchedule)
				end
			elseif mail:getMail_Type() == wd.MailType.PKMAPDROPEQUIP then
				mailNode = tolua.cast(cc.CSLoader:createNode("ui/mail/MailPKNode.csb"),"ccui.Widget")
				local timeLabel = tolua.cast(mailNode:getChildByName("Time_Label"), "ccui.Text")
				local year,month,day,hour,minute,second
				year = os.date("%Y",createTime)
				month = os.date("%m",createTime)
				day = os.date("%d",createTime)
				hour = os.date("%H",createTime)
				minute = os.date("%M",createTime)
				second = os.date("%S",createTime)
				local timeStr = string.format("%04d/%02d/%02d  %02d:%02d:%02d",year,month,day,hour,minute,second)
				timeLabel:setString(string.format("获胜时间: %s",timeStr))
				local equip = mail:getEquip()
				if equip:getServerId() >= 0 then
					elementTable[1] = ccui.RichElementText:create(1,cc.c3b(255,255,255),255,"您在PK地图中战胜 ","Helvetica",20)
					elementTable[2] = ccui.RichElementText:create(2,wd.battleColorTable["enemy"],255,mail:getSendName(),"Helvetica",20)
					elementTable[3] = ccui.RichElementText:create(3,cc.c3b(255,255,255),255," 获得 ","Helvetica",20)
					elementTable[4] = ccui.RichElementText:create(4,wd.colorTable[tonumber(equip:getColor())],255,equip:getName(),"Helvetica",20)
				end
				local getButton = tolua.cast(mailNode:getChildByName("Get_Button"), "ccui.Button")
				getButton:addTouchEventListener(
					function(sender,eventType)
						if eventType == ccui.TouchEventType.ended then
							if mail:getRead_state() ~= wd.MailReadState.REVENGEED then
								--领取
								self.dataHandler:requestGetItemInMail(mail:getMail_id())
							end
						end
					end
				)
				local equipSprite = tolua.cast(mailNode:getChildByName("Equip_Sprite"), "cc.Sprite")
				equipSprite:setSpriteFrame(string.format("%d.png",equip:getEquipId()%1000))
				local color = tolua.cast(mailNode:getChildByName("Color_Sprite"), "cc.Sprite")
				color:setSpriteFrame(string.format("%02d.png",equip:getColor()))
				local equipButton = tolua.cast(mailNode:getChildByName("Equip_Button"),"ccui.Button")
				equipButton:setEnabled(true)
				equipButton:addTouchEventListener(
					function(sender,eventType)
						if eventType == ccui.TouchEventType.ended then
							local layerClass = require("src.game.package.EquipTipsLayer")
							local layer = layerClass.create()
							layer:createLayerMenu(0, equip:getRegion(), 4, equip:getStrengthenLevel(),index-1)
							self:addChild(layer)
						end
					end
				)
			else
				mailNode = tolua.cast(cc.CSLoader:createNode("ui/mail/MailNode.csb"),"ccui.Widget")
				local timeLabel = tolua.cast(mailNode:getChildByName("Time_Label"), "ccui.Text")
				local year,month,day,hour,minute,second
				year = os.date("%Y",createTime)
				month = os.date("%m",createTime)
				day = os.date("%d",createTime)
				hour = os.date("%H",createTime)
				minute = os.date("%M",createTime)
				second = os.date("%S",createTime)
				local timeStr = string.format("%04d/%02d/%02d  %02d:%02d:%02d",year,month,day,hour,minute,second)
				timeLabel:setString(string.format("发放时间: %s",timeStr))
				
				local titleLabel =  tolua.cast(mailNode:getChildByName("Title_Label"), "ccui.Text")
				local titleStr , colorStr
				if mail:getMail_Type() == wd.MailType.SYSTEM_GIVE_AWARD then
					elementTable[1] = ccui.RichElementText:create(1,cc.c3b(255,255,255),255,"系统补偿奖励如下： ","Helvetica",20)
					titleStr = "系统补偿奖励"
				elseif mail:getMail_Type() == wd.MailType.ARENA_AWARD then
					local rank 
					if tonumber(mail:getTitle()) == nil then
						rank = 0
					else
						rank = tonumber(mail:getTitle())
					end
					local str = string.format("您在竞技场中排名第%d名,获得奖励如下:",rank)
					elementTable[1] = ccui.RichElementText:create(1,cc.c3b(255,255,255),255,str,"Helvetica",20)
					titleStr = "竞技排行奖励"
				end
				titleLabel:setString(titleStr)
				
				local itemListView = tolua.cast(mailNode:getChildByName("Item_ListView"), "ccui.ListView")
				itemListView:setSwallowTouches(false)
				local itemList,item
				if mail:getAccessoryList() then
					itemList = self.dataHandler:getMailItemList(mail:getMail_id(),mail:getAccessoryList())
					if itemList then
						for i,v in ipairs(itemList) do
							local btn = ccui.Button:create("role_equip_button.png", "role_equip_button.png", "", ccui.TextureResType.plistType)
							btn:setAnchorPoint(cc.p(0,0))
							local itemNode = tolua.cast(cc.CSLoader:createNode("ui/mail/RewardItemNode.csb"),"ccui.Widget")
							btn:addChild(itemNode)
                            local image = tolua.cast(itemNode:getChildByName("Tools_Sprite"), "cc.Sprite")
                            if tonumber(v.itemType) == wd.rewardItemType.MAIL_EQUIPMENT then
                                image:setSpriteFrame(string.format("%d.png",v.itemId%1000))    
                            else
                                image:setSpriteFrame(string.format("%d.png",v.itemId))
                            end
							local color = tolua.cast(itemNode:getChildByName("Color_Sprite"), "cc.Sprite")
							if tonumber(v.itemType) == wd.rewardItemType.MAIL_ITEM then
								item = wd.GlobalData:getInstance():getToolsItemInXml(v.itemId)
								
								colorStr = string.format("%02d.png",item:getQuality())
								btn:addTouchEventListener(
									function(sender,eventType)
										if eventType == ccui.TouchEventType.ended then
                                            local layerClass =  require("src.game.package.ToolsTipsLayer")
											local layer = layerClass.create()
											layer:createLayerMenu(v.itemId, true)
											self:addChild(layer)
										end
									end
								)
								if item:getQuality() == 5 then
									wd.itemEffect(image)
								end
							elseif tonumber(v.itemType) == wd.rewardItemType.MAIL_MONEY then 
								colorStr = string.format("%02d.png",4)
							elseif tonumber(v.itemType) == wd.rewardItemType.MAIL_GEM then 
								colorStr = string.format("%02d.png",5)
                            elseif tonumber(v.itemType) == wd.rewardItemType.MAIL_EQUIPMENT then 
                                local equip = wd.GlobalData:getInstance():getEquipItemInXml(v.itemId)
                                colorStr = string.format("%02d.png",equip:getColor())
                                btn:addTouchEventListener(
									function(sender,eventType)
										if eventType == ccui.TouchEventType.ended then
                                            local layerClass = require("src.game.shop.ArtifactTipsLayer")
                                            local layer = layerClass.create()
                                            layer:createLayerMenu(equip)
											self:addChild(layer)
										end
									end
								)
                                
								
							end
							color:setSpriteFrame(colorStr)
							local quantityLabel = tolua.cast(itemNode:getChildByName("Number_Label"), "ccui.Text")
							quantityLabel:setString(string.format("%d", v.itemCount))
							itemListView:pushBackCustomItem(btn)
						end
					end
				end
				local getButton = tolua.cast(mailNode:getChildByName("Get_Button"), "ccui.Button")
				getButton:addTouchEventListener(
					function(sender,eventType)
						if eventType == ccui.TouchEventType.ended then
							--领取
							self.dataHandler:requestGetItemInMail(mail:getMail_id())
						end
					end
				)
			end
			-- title
			if #elementTable > 0 then
				local richLabel = self:createRichLabelByElementList(elementTable)
				local richLabelBox = tolua.cast(mailNode:getChildByName("RichLabel_Layout"), "ccui.Layout")
				richLabelBox:setContentSize(richLabel:getContentSize())
				richLabelBox:addChild(richLabel)
				richLabel:setPosition(cc.p(richLabelBox:getContentSize().width/2,richLabelBox:getContentSize().height/2))
			end
			
			if mailNode then
				local background =  tolua.cast(mailNode:getChildByName("Background_Sprite"), "cc.Sprite")
				widget:setContentSize(background:getContentSize())
				widget:setAnchorPoint(cc.p(0,0))
				widget:setTag(index)
				widget:addChild(mailNode)
				mailNode:setPosition(cc.p(0,0))
				mailListView:pushBackCustomItem(widget)
			end
		end
	end
	
	local function getMailCallBack()
		--wd.showSystemTips("领取成功")
		if self.tickScheduleList ~= {} then
			for i,v in ipairs(self.tickScheduleList) do
				if v ~= nil then
					cc.Director:getInstance():getScheduler():unscheduleScriptEntry(self.tickScheduleList[i])
					self.tickScheduleList[i] = nil
				end
			end
		end
		wd.mailHandler :requestOpenMail()
		--self:clear()
	end
	
	local function getCallback(EventCustom)
        local getData = wd.GlobalData:getInstance():getMessage("Get_Item_Msg")
		local itemInfo = wd.getItemInfo(getData)
		if itemInfo == nil or itemInfo.name == nil or itemInfo.color == nil or itemInfo.count == nil then
			return
		end
		local msg = {}
		table.insert(msg,"获得")
		table.insert(msg,string.format("{t=[%s],c=[%d]}",itemInfo.name,itemInfo.color))
		table.insert(msg,string.format("*%d",itemInfo.count))
		wd.showRichTips(wd.tipsType.Get,msg)
    end

    local listener = cc.EventListenerCustom:create("Get_Item_Msg", getCallback)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local listener = cc.EventListenerCustom:create("Get_Mail", getMailCallBack)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local listener = cc.EventListenerCustom:create("MailList_Set", setMailList)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
end

function MailLayer:createRichLabelByElementList(richElementList)
	local richTextLabel = ccui.RichText:create()
	if richElementList then
		for i,v in ipairs(richElementList) do
			richTextLabel:pushBackElement(v)
		end
	end
	
	richTextLabel:formatText()
	--[[local size = richTextLabel:getContentSize()
	if size.width > self.labelViewSize.width then
		self.upHeight = math.ceil(size.width / self.labelViewSize.width) * size.height
		richTextLabel:ignoreContentAdaptWithSize(false)
		richTextLabel:setContentSize(self.labelViewSize.width,self.upHeight)
	end--]]
	--richTextLabel:setTag(self.frontTag)
	return richTextLabel
end

return MailLayer
