
local PKMapDataHandler = class("PKMapDataHandler")

local cclog = function(...)
    print(string.format(...))
end


function PKMapDataHandler:ctor()
	self:initData()
	self:registerEventListener()
end

function PKMapDataHandler:getInstance()
	if not self.instance then
		self.instance = PKMapDataHandler.new()
	end
	return self.instance
end

function PKMapDataHandler:destroyInstance()
    if self.instance then
        cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_PK_Player")
		cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_PK_Record")
        self.instance = nil
    end
end

function PKMapDataHandler:initData()
	self:initMapInfo()
	self.playerListSize = 0
	self.recordListSize = 0
	self.playerList = {}
	self.recordList = {}
end

function PKMapDataHandler:initMapInfo()
	self.mapInfoList = {}
	
	local mapConfig = require("res.config.exploration_map")
	for k,v in ipairs(mapConfig) do
		local map = {}
		map.id = v.map_id
		map.name = v.map_name
		map.level = v.level
		map.fight = v.fight
		map.reward = v.reward
		table.insert(self.mapInfoList,map)
	end

end

function PKMapDataHandler:getPKMapInfoList()
	return self.mapInfoList
end

function PKMapDataHandler:requestPKPlayerList()
	wd.TranscodingSend:getPKFightPlayer()
end

function PKMapDataHandler:requestBuyPKCount()
	wd.TranscodingSend:buyPkFightCount()
end

function PKMapDataHandler:requestFightInfo()
	wd.TranscodingSend:getPKRecord()
end

function PKMapDataHandler:requestFightPlayer()
	if self.pkId then
		wd.TranscodingSend:attackPKMapPlayer(self.pkId)
	end
end

function PKMapDataHandler:getPlayerList()
	return self.playerList
end

function PKMapDataHandler:getPlayerListSize()
	return self.playerListSize
end

function PKMapDataHandler:getRecordList()
	return self.recordList
end

function PKMapDataHandler:getRecordListSize()
	return self.recordListSize
end

function PKMapDataHandler:setFightPlayerId(id)
	self.pkId = id
end

function PKMapDataHandler:registerEventListener()
	--从服务器接收技能列表回调

	local function onGetPKPlayer(EventCustom)
		self.playerList = {}
		self.playerListSize = wd.GlobalData:getInstance():getPKPlayerListSize()
		for i = 0,self.playerListSize-1 do
			local pk = {}
			local player = wd.GlobalData:getInstance():getPkPlayer(i)
			pk.id = player:getRoleId()
			pk.level = player:getLevel()
			pk.power = player:getPower()
			pk.occupation = player:getOccupation()
			pk.sex = player:getSex()
			pk.pkValue = player:getPkValue()
			pk.isInProtect = player:getIsInProtect()
			pk.name = player:getName()
            pk.familyName = player:getFamilyName()
			table.insert(self.playerList,pk)
		end
		local event = cc.EventCustom:new("Update_PlayerList")
		cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
	end
	
	local listener = cc.EventListenerCustom:create("Get_PK_Player", onGetPKPlayer)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1)
	
	local function onGetPKRecord(EventCustom)
		self.recordList = {}
		self.recordListSize = wd.GlobalData:getInstance():getPKRecordList()
		for i = 0,self.recordListSize-1 do
			local pkRecord = {}
			local record = wd.GlobalData:getInstance():getPKRecord(i)
			pkRecord.pkType = record:getPkType()
			pkRecord.equipId = record:getEquipId()
			pkRecord.mapId = record:getMapId()
			pkRecord.name = record:getName()
			pkRecord.dropTime = record:getDropTime()
			pkRecord.currentTime = record:getCurrentTime()
			pkRecord.equipColor = record:getEquipColor()
			table.insert(self.recordList,pkRecord)
		end
		local event = cc.EventCustom:new("Update_PKRecord")
		cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
	end
	
	local listener = cc.EventListenerCustom:create("Get_PK_Record", onGetPKRecord)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1)
	
end


return PKMapDataHandler
