
local PackageEquipLayer = class("PackageEquipLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function PackageEquipLayer.create()
    local layer = PackageEquipLayer.new()
    layer:createLayerMenu()
    return layer
end

function PackageEquipLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
    self.capacity = nil
    self.equipScroll = nil
    self.filterType = 0
    self.filterId = 0
end

function PackageEquipLayer:capacityRefresh()
    local role = wd.GlobalData:getInstance():getRoleData()
    self.capacity:setString(string.format("%d/%d",  wd.GlobalData:getInstance():getEquipItemCount(), role:getPackageCapacity()))
end

function PackageEquipLayer:filter(filterType, filterId, toTop)  --filterType 0 = no filter  1 = region 2 = color

    self.equipScroll:removeAllChildren()
    
    self:capacityRefresh()
    
    if toTop == true then
        self.equipScroll:jumpToTop()
    end
    
    self.filterType = filterType
    self.filterId = filterId
    
    local function attrCallback(sender,eventType)
        if eventType == ccui.TouchEventType.ended then
            local layerClass = require("src.game.package.EquipTipsLayer")
            local layer = layerClass.create()
            layer:createLayerMenu(sender:getTag(), wd.WearRegion.NOTHING, 0, -1)
            self:addChild(layer)
        end
    end

    local number = 0
    
    if filterType == wd.FilterType.REGION then
        number = wd.GlobalData:getInstance():filterEquipListForRegion(filterId)

    elseif filterType == wd.FilterType.COLOR then
        number = wd.GlobalData:getInstance():filterEquipListForColor(filterId)

    else
        number = wd.GlobalData:getInstance():getEquipItemCount()
    end
    

    --local scrollHeight = self.visibleSize.height - 88 - 83
    --local scrollWidth = 1000
    local innerHeight = math.floor((number+2)/3)*180
    local innerWidth = 1000 --scrollWidth

    --self.equipScroll:setContentSize(cc.size(scrollWidth, scrollHeight))
    self.equipScroll:setInnerContainerSize(cc.size(innerWidth, innerHeight))

    --innerHeight = self.equipScroll:getInnerContainerSize().height
    
    self:dynamicLoading(self.equipScroll)
    
end

function PackageEquipLayer:dynamicLoading(scroll)
    local count = 2 -- 2 + 1
    local curCount = scroll:getChildrenCount()
	
    local layout = scroll:getInnerContainer()
    local y = layout:getPositionY()
    
    if curCount == 0 then
        count = 14 --  14 + 1
    end 
    
    local number = wd.GlobalData:getInstance():getEquipItemCount()
    

    if curCount >= number then 
        return
    end
    
    local innerHeight = self.equipScroll:getInnerContainerSize().height
    local innerWidth = self.equipScroll:getInnerContainerSize().width
    
    local height = math.floor(curCount/3)*180
        
    if (height - y) < innerHeight + 180 then
    
        local function attrCallback(sender,eventType)
            if eventType == ccui.TouchEventType.ended then

                local layerClass = require("src.game.package.EquipTipsLayer")
                local layer = layerClass.create()
                layer:createLayerMenu(sender:getTag(), wd.WearRegion.NOTHING, 0, -1)
                self:addChild(layer)
            end
        end
    
        for i=curCount, curCount+count do
			
            local tag
            
            if self.filterType == wd.FilterType.REGION then
                tag = wd.GlobalData:getInstance():getFilterEquipListTag(i)
            elseif self.filterType == wd.FilterType.COLOR then
                tag = wd.GlobalData:getInstance():getFilterEquipListTag(i)
            else
                tag = i
            end
            
            
            local item = wd.GlobalData:getInstance():getEquipItem(tag)
            
            if item == nil then
                break
            end
            
            local color = item:getColor()

            if item:getQuality() >= 2 then
                color = 6
            end
        
            local btn = ccui.Button:create("package_subbox.png", "package_subbox.png", "", ccui.TextureResType.plistType)
            btn:setAnchorPoint(cc.p(0,0))
            btn:setPosition( (innerWidth - btn:getContentSize().width)/2 * (i%3), innerHeight - 160 - math.floor(i/3)*180)
            btn:setTag(tag)
            btn:addTouchEventListener(attrCallback)
        
            local equipNode = tolua.cast(cc.CSLoader:createNode("ui/package/EquipNode.csb"),"ccui.Widget")
            btn:addChild(equipNode)
        
            local image = tolua.cast(equipNode:getChildByName("Equip_Sprite"), "cc.Sprite")
            local id = item:getEquipId()
            image:setSpriteFrame(string.format("%d.png",id%1000))
        
            wd.equipEffect(item, image)
        
            local colorSprite = tolua.cast(equipNode:getChildByName("Color_Sprite"), "cc.Sprite")
            colorSprite:setSpriteFrame(string.format("%02d.png",color))
        
            local title = tolua.cast(equipNode:getChildByName("Job_Title"), "cc.Sprite")
            if item:getOccupation() <= 0 then
                title:setVisible(false)
            else
                title:setSpriteFrame(wd.getEquipTitleName(item:getOccupation()))
            end
        
            local levelLabel = tolua.cast(equipNode:getChildByName("Level_Label"), "ccui.TextBMFont")
            levelLabel:setString(string.format("Lv%d",item:getLevel()))
        
            local nameLabel = tolua.cast(equipNode:getChildByName("Name_Label"), "ccui.Text")
            nameLabel:setColor(wd.colorType(color))
            
            if  item:getQuality() >= 2 and item:getStrengthenLevel() >= 15 then
                nameLabel:setString(string.format("%s%s+%d",wd.getEquipTitle(item:getOccupation()), item:getName(), item:getStrengthenLevel()))
            elseif item:getStrengthenLevel() >0 then
                nameLabel:setString(string.format("%s+%d",item:getName(), item:getStrengthenLevel()))
            else
                nameLabel:setString(item:getName())
            end
            
            local lockCheck = tolua.cast(ccui.Helper:seekWidgetByName(equipNode,"Lock_Check"), "ccui.CheckBox")
            if item:getLocked() ~= 0 then
                lockCheck:setSelected(true)
            end
            
            lockCheck:addEventListener(
                function(sender,eventType)
                    if eventType == ccui.CheckBoxEventType.selected then
                        wd.TranscodingSend:setEquipLocked(item:getServerId(), 1)
                    elseif  eventType == ccui.CheckBoxEventType.unselected then
                        wd.TranscodingSend:setEquipLocked(item:getServerId(), 0)
                    end
                end
            )
            
            local regionLabel = tolua.cast(equipNode:getChildByName("Region_Label"), "ccui.Text")
            regionLabel:setString(string.format("位置：%s",wd.getRegionString(item:getRegion())))
        
            self.equipScroll:addChild(btn)
        end
    end
    
end

function PackageEquipLayer:updateFliter()
    self:filter(self.filterType, self.filterId, true)
end

function PackageEquipLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/package/PackageEquipScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)

    local backBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Back_Button"), "ccui.Widget")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Equip_AttributeChange")
                cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Equip")
                self:removeFromParent()
            end
        end
    )
    
    local toolsBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Tools_Button"), "ccui.Button")
    toolsBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Equip_AttributeChange")
                cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Equip")
                local layerClass = require("src.game.package.PackageToolsLayer")
                local layer = layerClass.create()
                self:getParent():addChild(layer)
                self:removeFromParent()
            end
        end
    )
    
	local soulBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Soul_Button"), "ccui.Button")
    soulBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Equip_AttributeChange")
                cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Equip")
                local layerClass = require("src.game.package.PackageSoulLayer")
                local layer = layerClass.create()
                self:getParent():addChild(layer)
                self:removeFromParent()
            end
        end
    )
	
    local filterBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Filter_Button"), "ccui.Button")
    filterBtn:setPressedActionEnabled(true)
    filterBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                local layerClass = require("src.game.package.FilterLayer")
                local layer = layerClass.create()
                self:addChild(layer)
            end
        end
    )
    
    local allSaleBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"AllSale_Button"), "ccui.Button")
    allSaleBtn:setPressedActionEnabled(true)
    allSaleBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                local layerClass = require("src.game.package.AllSaleLayer")
                local layer = layerClass.create()
                self:addChild(layer)
            end
        end
    )
    
    
    --local capcityBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"AddSize_Button"), "ccui.Button")
    local capcityBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Capacity_Button"), "ccui.Button")
    capcityBtn:setPressedActionEnabled(true)
    capcityBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                local layerClass = require("src.tips.TipsBoxLayer")
                local msgTable = {}
                local msg = {}
                local role = wd.GlobalData:getInstance():getRoleData()
                local gem
                if role:getPackageCapacity() < 250 then
                    table.insert(msg,"是否消耗")
                    if role:getPackageCapacity() < 150 then
                        gem = 50
                    else
                        gem = 100
                    end
                    table.insert(msg,string.format("{y=[%d元宝]}",gem))
                    table.insert(msg,"扩展到")
                    table.insert(msg,string.format("{g=[%d]}",role:getPackageCapacity()+10))
                    table.insert(msg,"容量?")
                else
                    table.insert(msg,"背包已达最大容量")
                end
                table.insert(msgTable,msg)

                
                local function sureCallback()
                    if wd.GlobalData:getInstance():getRoleGem() < gem then
                        local layerClass = require("src.game.charge.ChargeTipsScene")
                        local layer = layerClass:create()
                        self:getParent():addChild(layer)
                    else
					    wd.TranscodingSend:expandPackage()
                    end
                    
                end
                self.tipsLayer = layerClass.create("capacity_expand.png", msgTable,sureCallback)
                self:addChild(self.tipsLayer)
            end
        end
    )
    
    
    local function scrollCallback(sender,eventType)
        self:dynamicLoading(sender)
    end
    
    self.equipScroll = tolua.cast(ccui.Helper:seekWidgetByName(node,"Equip_Scroll"), "ccui.ScrollView")
    self.equipScroll:addEventListener(scrollCallback)
    
    self.capacity = tolua.cast(ccui.Helper:seekWidgetByName(node,"Size_Label"), "ccui.Text")
    
    self:filter(wd.FilterType.NO_FLITER, 0, true)
    
    local function equipAttributeChangeCallBack()
		--wd.showAttributeChangeTip()
		local oldRole = wd.GlobalData:getInstance():getOldRoleData()
		local newRole = wd.GlobalData:getInstance():getRoleData()
		local roleAttributeClass = require("src.game.RoleAttribute"):getInstance()
		for i,v in pairs(roleAttributeClass.RoleBaseAttribute) do
			local changeValue = v.getFunc(newRole) - v.getFunc(oldRole)
			if changeValue ~= 0 then
				local sign = (changeValue < 0) and "" or "+"
				local color = (changeValue < 0) and cc.c3b(255,0,0) or cc.c3b(0,255,0)
				--local x,y = equipPanel:getPosition()
				local x = self.visibleSize.width/2
				local y = self.visibleSize.height/2
				if i == "CritDam" then
					changeValue = changeValue/100
				end
				changeValue = tostring(changeValue)
				if i == "Vertigo" or i == "Manaprevent" or i == "Reincarnate" or i == "Drainlife" or i == "CritDam" then
					changeValue = changeValue.."%"
				end
				wd.showAttributeTips(string.format("%s %s%s",v.name,sign,changeValue),color,35,cc.p(x,y))
			end
		end
	end

	--local listener_AttributeChange = cc.EventListenerCustom:create("Equip_AttributeChange", equipAttributeChangeCallBack)
	--cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener_AttributeChange, 1); 
	
	
    local function updateCallback(EventCustom)
        self:filter(wd.FilterType.NO_FLITER, 0, true)
    end
	
    local listener = cc.EventListenerCustom:create("Update_Equip", updateCallback)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
    
end


return PackageEquipLayer