
local PackageSoulLayer = class("PackageSoulLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function PackageSoulLayer.create()
    local layer = PackageSoulLayer.new()
    layer:createLayerMenu()
    return layer
end

function PackageSoulLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
    self.capacity = nil
    self.equipScroll = nil
    self.filterType = 0
    self.filterId = 0
end

function PackageSoulLayer:capacityRefresh()
    local role = wd.GlobalData:getInstance():getRoleData()
    self.capacity:setString(string.format("%d/%d",  wd.GlobalData:getInstance():getSoulItemCount(), role:getSoulCapacity()))
end

function PackageSoulLayer:filter(filterType, filterId, toTop)  --filterType 0 = no filter  1 = region 2 = color

    self.equipScroll:removeAllChildren()
    
    self:capacityRefresh()
    
    if toTop == true then
        self.equipScroll:jumpToTop()
    end
    
    self.filterType = filterType
    self.filterId = filterId


    local number =  wd.GlobalData:getInstance():getSoulItemCount()
    
   --[[ if filterType == wd.FilterType.REGION then
        number = wd.GlobalData:getInstance():filterEquipListForRegion(filterId)

    elseif filterType == wd.FilterType.COLOR then
        number = wd.GlobalData:getInstance():filterEquipListForColor(filterId)

    else
        number = wd.GlobalData:getInstance():getEquipItemCount()
    end
    --]]

    
    local innerHeight = math.floor((number+2)/3)*180
    local innerWidth = 1000 
    self.equipScroll:setInnerContainerSize(cc.size(innerWidth, innerHeight))

    --innerHeight = self.equipScroll:getInnerContainerSize().height
    
    self:dynamicLoading(self.equipScroll)
    
end

function PackageSoulLayer:dynamicLoading(scroll)
    local count = 2 -- 2 + 1
    local curCount = scroll:getChildrenCount()
    
    local layout = scroll:getInnerContainer()
    local y = layout:getPositionY()
    
    if curCount == 0 then
        count = 14 --  14 + 1
    end 
    
    local number = wd.GlobalData:getInstance():getSoulItemCount()
    

    if curCount >= number then 
        return
    end
    
    local innerHeight = self.equipScroll:getInnerContainerSize().height
    local innerWidth = self.equipScroll:getInnerContainerSize().width
    
    local height = math.floor(curCount/3)*180
        
    if (height - y) < innerHeight + 180 then
    
        local function attrCallback(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                local layerClass = require("src.game.soul.SoulTipsLayer")
                local layer = layerClass.create()
                layer:createLayerMenu(wd.soulHandler:setSoulItem(wd.GlobalData:getInstance():getSoulItem(sender:getTag())),3)
                self:addChild(layer)
            end
        end
    
        for i=curCount, curCount+count do
			
            local item = wd.GlobalData:getInstance():getSoulItem(i)
            
            if item == nil then
                break
            end
            
            
        
            local btn = ccui.Button:create("package_subbox.png", "package_subbox.png", "", ccui.TextureResType.plistType)
            btn:setAnchorPoint(cc.p(0,0))
            btn:setPosition( (innerWidth - btn:getContentSize().width)/2 * (i%3), innerHeight - 160 - math.floor(i/3)*180)
            btn:setTag(i)
            btn:addTouchEventListener(attrCallback)
        
            local soulNode = tolua.cast(cc.CSLoader:createNode("ui/package/soul/SoulPackageNode.csb"),"ccui.Widget")
            btn:addChild(soulNode)
		
            local image = tolua.cast(soulNode:getChildByName("Soul_Sprite"), "cc.Sprite")
            image:setSpriteFrame(string.format("%d.png",item:getSoulId()))
			
			wd.soulEffect(item:getQuality(),image)
			
			local color = item:getGrade()
            local colorSprite = tolua.cast(soulNode:getChildByName("Color_Sprite"), "cc.Sprite")
            colorSprite:setSpriteFrame(string.format("%02d.png",color))
        
            local gradeLabel = tolua.cast(soulNode:getChildByName("Grade_Label"), "ccui.Text")
            gradeLabel:setString(string.format("阶位：%d",item:getGrade()))
			
			local topGradeLabel = tolua.cast(soulNode:getChildByName("Top_Grade_Label"), "ccui.Text")
            topGradeLabel:setString(item:getGrade())
			
            local levelLabel = tolua.cast(soulNode:getChildByName("Level_Label"), "ccui.TextBMFont")
            levelLabel:setString(string.format("Lv%d",item:getLevel()))
        
            local nameLabel = tolua.cast(soulNode:getChildByName("Name_Label"), "ccui.Text")
            nameLabel:setColor(wd.colorType(color))
            
            if item:getSoulGrade() >0 then
                nameLabel:setString(string.format("%s+%d",item:getName(), item:getSoulGrade()))
            else
                nameLabel:setString(item:getName())
            end
        
            self.equipScroll:addChild(btn)
        end
    end
    
end

function PackageSoulLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/package/PackageSoulScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)

    local backBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Back_Button"), "ccui.Widget")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Item_Msg")
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Soul")
                self:removeFromParent()
            end
        end
    )
    
    local toolsBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Tools_Button"), "ccui.Button")
    toolsBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Item_Msg")
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Soul")
                local layerClass = require("src.game.package.PackageToolsLayer")
                local layer = layerClass.create()
                self:getParent():addChild(layer)
                self:removeFromParent()
            end
        end
    )
	
	local equipBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Equip_Button"), "ccui.Button")
    equipBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Item_Msg")
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Update_Soul")
                local layerClass = require("src.game.package.PackageEquipLayer")
                local layer = layerClass.create()
                self:getParent():addChild(layer)
                self:removeFromParent()
            end
        end
    )
    
    local allResolveBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"AllResolve_Button"), "ccui.Button")
    allResolveBtn:setPressedActionEnabled(true)
    allResolveBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                local layerClass = require("src.game.package.AllResolveLayer")
                local layer = layerClass.create()
                self:addChild(layer)
            end
        end
    )
    
    local capcityBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Capacity_Button"), "ccui.Button")
    capcityBtn:setPressedActionEnabled(true)
    capcityBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                local layerClass = require("src.tips.TipsBoxLayer")
                local msgTable = {}
                local msg = {}
                local gem
                local role = wd.GlobalData:getInstance():getRoleData()
                if role:getSoulCapacity() < 250 then
                    table.insert(msg,"是否消耗")
                    if role:getSoulCapacity() < 150 then
                        gem = 50
                    else
                        gem = 100
                    end
                    table.insert(msg,string.format("{y=[%d元宝]}",gem))
                    table.insert(msg,"扩展到")
                    table.insert(msg,string.format("{g=[%d]}",role:getSoulCapacity()+10))
                    table.insert(msg,"容量?")
                else
                    table.insert(msg,"背包已达最大容量")
                end
                table.insert(msgTable,msg)

                
                local function sureCallback()
                    if wd.GlobalData:getInstance():getRoleGem() < gem then
                        local layerClass = require("src.game.charge.ChargeTipsScene")
                        local layer = layerClass:create()
                        self:getParent():addChild(layer)
                    else
					    wd.soulHandler:requestExpandSoulPackage()
                    end
                    
                end
                self.tipsLayer = layerClass.create("capacity_expand.png", msgTable,sureCallback)
                self:addChild(self.tipsLayer)
            end
        end
    )
    
    
    local function scrollCallback(sender,eventType)
        self:dynamicLoading(sender)
    end
    
    self.equipScroll = tolua.cast(ccui.Helper:seekWidgetByName(node,"Equip_Scroll"), "ccui.ScrollView")
    self.equipScroll:addEventListener(scrollCallback)
    
    self.capacity = tolua.cast(ccui.Helper:seekWidgetByName(node,"Size_Label"), "ccui.Text")
    local role = wd.GlobalData:getInstance():getRoleData()
    self.capacity:setString(string.format("%d/%d",  wd.GlobalData:getInstance():getSoulItemCount(), role:getSoulCapacity()))
    self:filter(wd.FilterType.NO_FLITER, 0, true)
	
	
    local function updateCallback(EventCustom)
        self:filter(wd.FilterType.NO_FLITER, 0, true)
    end
	
    local listener = cc.EventListenerCustom:create("Update_Soul", updateCallback)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local function getCallback(EventCustom)
        local getData = wd.GlobalData:getInstance():getMessage("Get_Item_Msg")
		local itemInfo = wd.getItemInfo(getData)
		if itemInfo == nil or itemInfo.name == nil or itemInfo.color == nil or itemInfo.count == nil then
			return
		end
		local msg = {}
		table.insert(msg,"获得")
		table.insert(msg,string.format("{t=[%s],c=[%d]}",itemInfo.name,itemInfo.color))
		table.insert(msg,string.format("*%d",itemInfo.count))
		wd.showRichTips(wd.tipsType.Get,msg)
    end
	
	local listener = cc.EventListenerCustom:create("Get_Item_Msg", getCallback)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
    
end


return PackageSoulLayer