local ToolsTipsLayer = class("ToolsTipsLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function ToolsTipsLayer.create()
    local layer = ToolsTipsLayer.new()
    return layer
end

function ToolsTipsLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
    self.quantityLabel = nil
    self.toolsId = 0
	self.isInXml = false
end

function ToolsTipsLayer:registerEventListener()

    local function getCallback(EventCustom)
        local getData = wd.GlobalData:getInstance():getMessage("Get_Item")
        if getData:len() >= 5 then
        
            local layerClass = require("src.game.package.ToolsGetLayer")
            local layer = layerClass.create()
            layer:createLayerMenu(getData)
            self:getParent():addChild(layer)
        end
        
        local quantity = wd.GlobalData:getInstance():getToolsItemCountForId(self.toolsId)
        cclog("tools %d  quantity %d",self.toolsId, quantity)
        if quantity <= 0 then
            self:unregisterEventListener()
            self:clear()
        else
            self.quantityLabel:setString(string.format("%d", quantity))
        end
    end
	
    local listener = cc.EventListenerCustom:create("Get_Item", getCallback)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	
end

function ToolsTipsLayer:unregisterEventListener()
    cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Item")
	
end

function ToolsTipsLayer:createLayerMenu(toolsId, isPreview)
    local node = tolua.cast(cc.CSLoader:createNode("ui/package/ToolsTipsLayer.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)
    
    local item = nil
    if isPreview == true then
        item = wd.GlobalData:getInstance():getToolsItemInXml(toolsId)
        self.isInXml = true
    else
        item = wd.GlobalData:getInstance():getToolsItemForId(toolsId)
        self.isInXml = false
    end

    self.toolsId = toolsId

    local backBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Back_Button"), "ccui.Widget")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:unregisterEventListener()
                self:clear()
            end
        end
    )
    
    local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Main"), "ccui.Widget")
    local image = tolua.cast(mainPanel:getChildByName("Tools_Sprite"), "cc.Sprite")
    image:setSpriteFrame(string.format("%d.png",item:getToolsId()))
    if item:getQuality() == 5 then
		wd.itemEffect(image)
	end
    local color = tolua.cast(mainPanel:getChildByName("Color_Sprite"), "cc.Sprite")
    color:setSpriteFrame(string.format("%02d.png",item:getQuality()))
    
    local nameLabel = tolua.cast(mainPanel:getChildByName("Name_Label"), "ccui.Text")
    nameLabel:setString(item:getName())
	
	
    local quantityTitle = tolua.cast(mainPanel:getChildByName("Number_Title"), "cc.Sprite")
    local quantityLabel = tolua.cast(mainPanel:getChildByName("Number_Label"), "ccui.Text")
	quantityLabel:setString(string.format("%d", item:getQuantity()))
	
    self.quantityLabel = quantityLabel
	quantityLabel:setVisible(not self.isInXml)
    quantityTitle:setVisible(not self.isInXml)
	
    local decsLabel = tolua.cast(mainPanel:getChildByName("Desc_Text"), "ccui.Text")
    decsLabel:setContentSize(cc.size(288, 100))
    decsLabel:setString(item:getDescription())
    
    if item:getDetail() == 1 then
    
        local btn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Contents_Button"), "ccui.Widget")
        btn:addTouchEventListener(
            function(sender,eventType)
                if eventType == ccui.TouchEventType.ended then
                    local layerClass = require("src.game.package.ToolsGetPreviewLayer")
                    local layer = layerClass.create()
                    layer:createLayerMenu(toolsId)
                    self:addChild(layer)
                end
            end
        )
    
    end
    
    
    local level = item:getLevel()
    
    
	local function useItem(count)
		local role = wd.GlobalData:getInstance():getRoleData()
		if role:getLevel() >= level then
			if wd.GlobalData:getInstance():useToolsItemForId(toolsId, 0) > 0 then
		
				if toolsId == wd.ItemId.SuperChest then
					if wd.GlobalData:getInstance():useToolsItemForId(wd.ItemId.SuperAssociate, 0) < 1 then
						wd.showRichTips(4,"需要超级钥匙才能打开")
						return
					end 
				end
				
				if toolsId == wd.ItemId.SilverChest then
					if wd.GlobalData:getInstance():useToolsItemForId(wd.ItemId.SilverAssociate, 0) < 1 then
						wd.showRichTips(4,"需要白银钥匙才能打开")
						return
					end
				end
				
				if toolsId < 1017 or toolsId > 1035 then
					if role:getPackageCapacity()-3 <= wd.GlobalData:getInstance():getEquipItemCount() then
						wd.showRichTips(4,"背包将满,请扩展背包或清理装备")
						return
					end
				end
				--wd.GlobalData:getInstance():useToolsItemForId(item:getToolsId(), 1)
				wd.TranscodingSend:setToolsUse(toolsId, count)
			else
				wd.showRichTips(4,"物品不存在")
				self:unregisterEventListener()
				self:clear()
			end
			
		else
			wd.showRichTips(4,string.formar("需要达到%d级才能打开", item:getLevel()))
		end
	end
	self:registerEventListener()
	local btn,tenOpenBtn
	if (toolsId < wd.ItemId.Soul_1 or toolsId > wd.ItemId.Soul_6) and (toolsId ~= wd.ItemId.SoulSpecial_1 and toolsId ~= wd.ItemId.SoulSpecial_2) then
		if item:getType() == 2 and self.isInXml == false then
			btn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Open_Button"), "ccui.Widget")
			btn:addTouchEventListener(
				function(sender,eventType)
					if eventType == ccui.TouchEventType.ended then
						useItem(1)
					end
				end
			)
			tenOpenBtn= tolua.cast(ccui.Helper:seekWidgetByName(node,"Ten_Open_Button"), "ccui.Widget")
			tenOpenBtn:addTouchEventListener(
				function(sender,eventType)
					if eventType == ccui.TouchEventType.ended then
						local useCount,chestCount,associateCount = 0,0,0
						if toolsId == wd.ItemId.SuperChest or toolsId == wd.ItemId.SuperAssociate then
							chestCount = wd.GlobalData:getInstance():getToolsItemCountForId(wd.ItemId.SuperChest)
							associateCount = wd.GlobalData:getInstance():getToolsItemCountForId(wd.ItemId.SuperAssociate)
						elseif toolsId == wd.ItemId.SilverChest or toolsId == wd.ItemId.SilverAssociate then
							chestCount = wd.GlobalData:getInstance():getToolsItemCountForId(wd.ItemId.SilverChest)
							associateCount = wd.GlobalData:getInstance():getToolsItemCountForId(wd.ItemId.SilverAssociate)
						end
						if chestCount ~= 0 then
							useCount = chestCount >= associateCount and associateCount or chestCount
						else
							useCount = wd.GlobalData:getInstance():getToolsItemCountForId(toolsId)
						end
						if useCount >= 10 then
							useCount = 10
						end
						useItem(useCount)
					end
				end
			)
			
		else
			btn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Close_Button"), "ccui.Widget")
			btn:addTouchEventListener(
				function(sender,eventType)
					if eventType == ccui.TouchEventType.ended then
						self:unregisterEventListener()
						self:clear()
					end
				end
			)
		end
    else
		if not isPreview then
			btn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Compound_Button"), "ccui.Widget")
			btn:addTouchEventListener(
				function(sender,eventType)
					if eventType == ccui.TouchEventType.ended then
						wd.soulHandler:requestSoulCompound(toolsId)
						self:unregisterEventListener()
						self:clear()
					end
				end
			)
		else
			btn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Close_Button"), "ccui.Widget")
			btn:addTouchEventListener(
				function(sender,eventType)
					if eventType == ccui.TouchEventType.ended then
						self:unregisterEventListener()
						self:clear()
					end
				end
			)
		end
	end
    btn:setPressedActionEnabled(true)
    btn:setVisible(true)
	if tenOpenBtn then
		tenOpenBtn:setPressedActionEnabled(true)
		tenOpenBtn:setVisible(true)
	end
	
end

function ToolsTipsLayer:clear()
	self:removeFromParent()
end

return ToolsTipsLayer