local SettingLayer = class("SettingLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function SettingLayer.create()
    local layer = SettingLayer.new()
	layer:createLayerMenu()
    return layer
end

function SettingLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
end

function SettingLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/setting/SettingScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)
   
    local backBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Close_Button"), "ccui.Widget")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:removeFromParent()
            end
        end
    )
	
	local loginBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Login_Button"), "ccui.Button")
    loginBtn:setPressedActionEnabled(true)
    loginBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                --wd.showSystemTips("暂未开放")
                wd.SdkApi:logoutSdk()

                wd.TranscodingSend:disconnectServer()

                wd.GlobalData:destroyInstance()

                local scene = require("src.login.LoginScene")
                local gameScene = scene.create()

                if cc.Director:getInstance():getRunningScene() then
                    cc.Director:getInstance():replaceScene(gameScene)
                else
                    cc.Director:getInstance():runWithScene(gameScene)
                end

            end
        end
    )
	
	local selectBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Select_Button"), "ccui.Button")
    selectBtn:setPressedActionEnabled(true)
    selectBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                --wd.showSystemTips("暂未开放")
                wd.SdkApi:logoutSdk()

                wd.TranscodingSend:disconnectServer()

                wd.GlobalData:destroyInstance()

                local scene = require("src.login.LoginScene")
                local gameScene = scene.create()

                if cc.Director:getInstance():getRunningScene() then
                    cc.Director:getInstance():replaceScene(gameScene)
                else
                    cc.Director:getInstance():runWithScene(gameScene)
                end

            end
        end
    )
	
	local announceBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Announce_Button"), "ccui.Button")
    announceBtn:setPressedActionEnabled(true)
    announceBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                --wd.showSystemTips("暂未开放")
				local class = require("src.update.AnnounceLayer")
				local announcement = class.create()
				announcement:createLayerMenu()
				self:addChild(announcement)
            end
        end
    )
	
	local helpBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Help_Button"), "ccui.Button")
    helpBtn:setPressedActionEnabled(true)
    helpBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                --wd.showSystemTips("暂未开放")
				local layerClass = require("src.game.setting.HelpLayer")
				local layer = layerClass.create(wd.helpType.Total)
				self:addChild(layer)
            end
        end
    )
	
	local giftBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Gift_Button"), "ccui.Button")
    giftBtn:setPressedActionEnabled(true)
    giftBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                --wd.showSystemTips("暂未开放")
				local layerClass = require("src.game.setting.CdkeyLayer")
				local layer = layerClass.create(wd.helpType.Total)
				self:addChild(layer)
            end
        end
    )
	
	local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Main"), "ccui.Widget")
	local versionLabel = tolua.cast(mainPanel:getChildByName("Version_Label"),"ccui.Text")
	if cc.UserDefault:getInstance():getStringForKey("version") then
		versionLabel:setString(string.format("版本号:%s",cc.UserDefault:getInstance():getStringForKey("version")))
	end
	
    
    local uid = tolua.cast(mainPanel:getChildByName("Uid_Label"),"ccui.Text")
    uid:setString("UID:"..wd.GlobalData:getInstance():getRoleData():getRoleId())
    -- uid:setString("UID:"..wd.GlobalData:getInstance():getUserId())
	local panel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_3"), "ccui.Widget")
	
	local soundBtn = tolua.cast(ccui.Helper:seekWidgetByName(panel,"Sound_Button"), "ccui.Widget")
	
	local soundDisable = tolua.cast(panel:getChildByName("Sound_Disable"), "cc.Sprite")
	soundDisable:setVisible(not (cc.UserDefault:getInstance():getBoolForKey("Sound")))
    soundBtn:setPressedActionEnabled(true)
    soundBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				local flag
				if cc.UserDefault:getInstance():getBoolForKey("Sound") then
					flag = false
				else
					flag = true
				end
                wd.audioHandler:setEffectState(flag)
				soundDisable:setVisible(not flag)
			end
        end
    )
	
	local musicBtn = tolua.cast(ccui.Helper:seekWidgetByName(panel,"Music_Button"), "ccui.Widget")
	local musicDisable =  tolua.cast(panel:getChildByName("Music_Disable"), "cc.Sprite")
	musicDisable:setVisible(not(cc.UserDefault:getInstance():getBoolForKey("Music_Main")))
    musicBtn:setPressedActionEnabled(true)
    musicBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				local flag
				if cc.UserDefault:getInstance():getBoolForKey("Music_Main") then
					flag = false
				else
					flag = true
				end
				wd.audioHandler:setMainBackgroundMusicState(flag)
				musicDisable:setVisible(not flag)
            end
        end
    )
   
end


return SettingLayer