local BuyItemLayer = class("BuyItemLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function BuyItemLayer.create()
    local layer = BuyItemLayer.new()
    return layer
end

function BuyItemLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
	self.requestBuyCount = 0
	self.dataHandler = wd.shopHandler
end

function BuyItemLayer:clear()
	cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Buy_Item_Count")
    self:removeFromParent()
end

function BuyItemLayer:createLayerMenu(mallItem)
	local itemId = mallItem:getMallItemId()
	local limitCount = mallItem:getBuyLimit()
	local price = mallItem:getPrice()
	
    local node = tolua.cast(cc.CSLoader:createNode("ui/shop/BuyItemLayer.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)
    local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Main"), "ccui.Widget")
	
    local backBtn = tolua.cast(mainPanel:getChildByName("Close_Button"), "ccui.Button")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				self:clear()
            end
        end
    )
    if itemId then
		local item = wd.GlobalData:getInstance():getToolsItemInXml(itemId)
		
		local itemNode = tolua.cast(mainPanel:getChildByName("ItemNode"), "ccui.Widget")
		local image = tolua.cast(itemNode:getChildByName("Tools_Sprite"), "cc.Sprite")
		image:setSpriteFrame(string.format("%d.png",itemId))
		image:setVisible(true)
		if item:getQuality() == 5 then
			wd.itemEffect(image)
		end
		local color = tolua.cast(itemNode:getChildByName("Color_Sprite"), "cc.Sprite")
		color:setSpriteFrame(string.format("%02d.png",item:getQuality()))
		
		local nameLabel = tolua.cast(itemNode:getChildByName("Name_Label"), "ccui.Text")
		nameLabel:setString(item:getName())
		nameLabel:setVisible(true)
		
		local leftCount = self.dataHandler:getLeftCountById(itemId)
		local limitLabel = tolua.cast(mainPanel:getChildByName("Limit_Label"), "ccui.Text")
		--local canBuyCount = (limitCount-hadBuyCount > 0 and limitCount-hadBuyCount or 0 )
		limitLabel:setString(leftCount)
		
		local priceLabel = tolua.cast(mainPanel:getChildByName("Price_Label"), "ccui.Text")
		priceLabel:setString(price)
		
		local numberLabel = tolua.cast(mainPanel:getChildByName("Number_Label"), "ccui.Text")
		
		local enterBtn = tolua.cast(mainPanel:getChildByName("Enter_Button"), "ccui.Button")
		enterBtn:setPressedActionEnabled(true)
		enterBtn:addTouchEventListener(
			function(sender,eventType)
				if eventType == ccui.TouchEventType.ended then
                    local count = numberLabel:getString()
                    count = tonumber(count)
                    if wd.GlobalData:getInstance():getRoleGem() >= price*count then
                        self.requestBuyCount = count
                        wd.TranscodingSend:buyItem(itemId,count)
                    else
                        local layerClass = require("src.game.charge.ChargeTipsScene")
                        local layer = layerClass:create()
                        self:getParent():addChild(layer)
                        self:removeFromParent()
                    end
				end
			end
		)
		
		local cancelBtn = tolua.cast(mainPanel:getChildByName("Cancel_Button"), "ccui.Button")
		cancelBtn:setPressedActionEnabled(true)
		cancelBtn:addTouchEventListener(
			function(sender,eventType)
				if eventType == ccui.TouchEventType.ended then
					self:removeFromParent()
				end
			end
		)
		
		local addBtn = tolua.cast(mainPanel:getChildByName("Add_Button"), "ccui.Button")
		addBtn:setPressedActionEnabled(true)
		addBtn:addTouchEventListener(
			function(sender,eventType)
				if eventType == ccui.TouchEventType.ended then
					local str = numberLabel:getString()
					str = tonumber(str)+1
					color = cc.c3b(255,255,255)
					if str >= leftCount then
						str = leftCount
						--color = cc.c3b(255,0,0)
					end
					numberLabel:setString(str)
					numberLabel:setColor(color)
					priceLabel:setString(price*str)
				end
			end
		)
		
		local addTenBtn = tolua.cast(mainPanel:getChildByName("Add_Ten_Button"), "ccui.Button")
		addTenBtn:setPressedActionEnabled(true)
		addTenBtn:addTouchEventListener(
			function(sender,eventType)
				if eventType == ccui.TouchEventType.ended then
					local str = numberLabel:getString()
					str = tonumber(str)+10
					color = cc.c3b(255,255,255)
					if str >= leftCount then
						str = leftCount
						--color = cc.c3b(255,0,0)
					end
					numberLabel:setString(str)
					numberLabel:setColor(color)
					priceLabel:setString(price*str)
				end
			end
		)
		
		
		local minusBtn = tolua.cast(mainPanel:getChildByName("Minus_Button"), "ccui.Button")
		minusBtn:setPressedActionEnabled(true)
		minusBtn:addTouchEventListener(
			function(sender,eventType)
				if eventType == ccui.TouchEventType.ended then
					local str = numberLabel:getString()
					color = cc.c3b(255,255,255)
					str = tonumber(str)-1
					if str < 1 then
						str = 1
					end
					numberLabel:setString(str)
					numberLabel:setColor(color)
					priceLabel:setString(price*str)
				end
			end
		)
		
		local function buyItemCallBack()
			if leftCount == 0 then
				leftCount = limitCount - self.requestBuyCount
			else
				leftCount = leftCount - self.requestBuyCount
			end
			self.dataHandler:updateLeftCountById(itemId,leftCount)
			self:clear()
		end
		local listenerBuyItem = cc.EventListenerCustom:create("Buy_Item_Count", buyItemCallBack)
		cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listenerBuyItem, 1)
	end
	
	
end


return BuyItemLayer