
local ShopDataHandler = class("ShopDataHandler")

local cclog = function(...)
    print(string.format(...))
end


function ShopDataHandler:ctor()
	self.showArtifactCount = 0
	self.mallItemList = {}
	self.mallItemListById = {}
	self.artifactList = {}
	self.artifactListById = {}
	self.hadBuyItemList = {}
	self.artifactShowList = {}
	self:initData()
	self:registerEventListener()
end

function ShopDataHandler:getInstance()
	if not self.instance then
		self.instance = ShopDataHandler.new()
	end
	return self.instance
end

function ShopDataHandler:destroyInstance()
	if self.instance then
        cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Open_Shop")
        self.instance = nil
    end
end

function ShopDataHandler:initData()
	self:setMallItemList()
	self:setArtifactList()
end

function ShopDataHandler:setMallItemList()
	self.mallItemCount = wd.GlobalData:getInstance():getMallItemCount()
	for i = 0,self.mallItemCount-1 do
		local mallItem = wd.GlobalData:getInstance():getMallItem(i)
		self.mallItemList[i] = mallItem
		self.mallItemListById[mallItem:getMallItemId()] = mallItem
	end
end

function ShopDataHandler:setArtifactList()
	self.artifactCount = wd.GlobalData:getInstance():getArtifactListSize()
	for i = 0,self.artifactCount -1 do
		local artifact = wd.GlobalData:getInstance():getArtifact(i)
		self.artifactList[i] = artifact
		self.artifactListById[artifact:getArtifactId()] = artifact
	end
end

function ShopDataHandler:getMallItemList()
	return self.mallItemList
end

function ShopDataHandler:getMallItem(tag)
	return self.mallItemList[tag]
end

function ShopDataHandler:getItemCount()
	return self.mallItemCount
end

function ShopDataHandler:getArtifactList()
	return self.artifactList
end

function ShopDataHandler:getArtifact(tag)
	return self.artifactList[tag]
end

function ShopDataHandler:getArtifactCount()
	return self.artifactCount
end

function ShopDataHandler:getArtifactById(id)
	return self.artifactListById[id]
end

function ShopDataHandler:getShowArtifactCount()
	return self.showArtifactCount
end

function ShopDataHandler:getShowArtifactId(tag)
	return self.artifactShowList[tag]
end

function ShopDataHandler:getLeftCountById(id)
	return self.hadBuyItemList[id] or 0
end

function ShopDataHandler:updateLeftCountById(id,count)
	self.hadBuyItemList[id] = count
end

function ShopDataHandler:requestOpenShop()
	wd.TranscodingSend:openShop()
end

function ShopDataHandler:requestRefreshArtifactList()
	wd.TranscodingSend:refreshBuyEquipment()
end

function ShopDataHandler:requestExchangeArtifact(equipId)
	self.buyEquipId = equipId
	wd.TranscodingSend:buyEquip(equipId)
end

function ShopDataHandler:getBuyEquipId()
	return self.buyEquipId
end

function ShopDataHandler:setArtifactShowList()
	local artifactListSize = wd.GlobalData:getInstance():getArtifactListSize()
	self.artifactShowList = {}
	if artifactListSize >0 then
		self.showArtifactCount = artifactListSize
		for i = 0,artifactListSize-1 do
			local artifact = wd.GlobalData:getInstance():getArtifact(i)
			self.artifactShowList[i] = artifact:getArtifactId()
			
		end
	end
end

function ShopDataHandler:registerEventListener()
	--从服务器接收技能列表回调

	local function openShopCallBack(EventCustom)
		local hadBuyItemListSize = wd.GlobalData:getInstance():getHadBuyItemListSize()
		if hadBuyItemListSize >0 then
			for i = 0,hadBuyItemListSize-1 do
				local hadBuyItem = wd.GlobalData:getInstance():getHadBuyItem(i)
				local id = hadBuyItem:getMallItemId()
				local number = hadBuyItem:getLeftNumber()
				self.hadBuyItemList[id] = number
			end
		end
		self:setArtifactShowList()
	end
	
	local listenerOpenShop = cc.EventListenerCustom:create("Open_Shop", openShopCallBack)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listenerOpenShop, 1)
end


return ShopDataHandler