require("src.game.skill.SkillConfig")
local SkillDataHandler = class("SkillDataHandler")

local cclog = function(...)
    print(string.format(...))
end


function SkillDataHandler:ctor()
	self.allSkillItem = {}
	self.allSkillIndexBySkillId = {}
	self.learnedSkillIdList = {}
	self.mySkillList = {}
	self.skillOrderList = {}
	self.skillOrderIdList = {}
	self.requsetOrderIdList = {}
	
	self.allBuffItem = {}
	self:registerEventListener()
end

function SkillDataHandler:getInstance()
	if not self.instance then
		self.instance = SkillDataHandler.new()
	end
	return self.instance
end

function SkillDataHandler:destroyInstance()
    if self.instance then
        self.instance = nil
		cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Skill_GetAllCanUseSkill")
        cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Skill_Use")
		cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Skill_Up")
    end
end

-- 存储所有技能信息
function SkillDataHandler:setAllSkillInfo()
	local skillCount = wd.GlobalData:getInstance():getSkillItemCount()
	for i = 0,skillCount-1 do 
		local skillItem = wd.GlobalData:getInstance():getSkillItem(i)
		if skillItem then
			self.allSkillItem[i+1] = skillItem
			self.allSkillIndexBySkillId[skillItem:getSkillId()] = skillItem
		end
	end
end

function SkillDataHandler:getAllSkillInfo()
	if #self.allSkillItem > 0 then
		return self.allSkillItem
	end
end

function SkillDataHandler:getSkillItemBySkillId(skillId)
	for i,v in ipairs(self.allSkillItem) do
		if v:getSkillId() == skillId then
			return v
		end
	end
end

--[[
mySkillList = {skillItem = skillItem , isLearned = bool}
--]]
-- 存储本职业所有一级技能
function SkillDataHandler:setMySkillList()
	self.mySkillList = {}
	if #self.allSkillItem > 0 then
		local role = wd.GlobalData:getInstance():getRoleData()
		local myOccupation = role:getOccupation()
		for i,v in ipairs(self.allSkillItem) do
			if v:getRoleOccupation() == myOccupation then
				local hasSet = false
				local skill = {}
				for index ,value in ipairs(self.learnedSkillIdList) do
					if math.abs(tonumber(value.skillId)- tonumber(v:getSkillId()))< 30 then
						hasSet = true
						if value.skillId == v:getSkillId() then
							skill.exp = value.exp
							skill.isLearned = true
							skill.skillItem = v
							table.insert(self.mySkillList, skill)
						end
					end
				end
				if not hasSet then
					if v:getLevel() == 1 then
						skill.isLearned = false
						skill.exp = 0
						skill.skillItem = v
						table.insert(self.mySkillList, skill)
					end
				end				
			end
		end
		self:setSkillOrderList()
	end
	local event = cc.EventCustom:new("SkillList_Set")
	cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
end


function SkillDataHandler:getMySkillList()
	if #self.mySkillList > 0 then
		return self.mySkillList
	else
		error("mySkillList set Error")
	end
end

function SkillDataHandler:getMySkillItemByTag(tag)
	if self.mySkillList[tag] then
		return self.mySkillList[tag]
	end
end

function SkillDataHandler:getNextSkillItemDescptionByCurrentSkillItem(curSkillItem)
	local curSkillItemId = curSkillItem:getSkillId()
	if self.allSkillIndexBySkillId[curSkillItemId+1] then
		return self.allSkillIndexBySkillId[curSkillItemId+1]:getDescription()
	end
end

function SkillDataHandler:getSkillNameBySkillId(skillId)
	if self.allSkillIndexBySkillId[skillId] then
		return self.allSkillIndexBySkillId[skillId]:getName()
	end
end

-- 获得技能顺序列表
function SkillDataHandler:getSkillOrderList()
	return self.skillOrderList
end

-- 设置已装备的技能
function SkillDataHandler:setSkillOrderList()
	self.skillOrderList = {}
	if #self.skillOrderIdList > 0 then
		for index,value in ipairs(self.skillOrderIdList) do
			for i,v in ipairs(self.mySkillList) do
				if value == v.skillItem:getSkillId() then
					table.insert(self.skillOrderList,v.skillItem)
					break
				end
			end
		end
	end
	
end

-- 请求技能装备
function SkillDataHandler:requestSetSkillOrderList(skillOrderList)
	for i = 1,4 do
		if skillOrderList[i] then
			self.requsetOrderIdList[i] = tonumber(skillOrderList[i]:getSkillId())
		else
			self.requsetOrderIdList[i] = 0
		end
	end
	wd.TranscodingSend:setSkillUse(self.requsetOrderIdList[1],self.requsetOrderIdList[2],self.requsetOrderIdList[3],self.requsetOrderIdList[4])
end

-- 设置已装备的技能Id
function SkillDataHandler:setSettingSkillData()
	local count = wd.GlobalData:getInstance():getSettingSkillListCount()
	if count >0 then
		for i = 0,count -1 do
			local skillId = wd.GlobalData:getInstance():getSettingSkill(i)
			table.insert(self.skillOrderIdList,skillId)
		end
	end
end

-- 获取身上技能丹数量
function SkillDataHandler:getSkillUpgradeDrugCount()
	local count = wd.GlobalData:getInstance():getToolsItemCountForId(wd.SKILL_UPGRADE_DRUG_ID)
	return count
end

-- 获取身上进阶丹数量
function SkillDataHandler:getSkillAdvancedDrugCount()
	local count = wd.GlobalData:getInstance():getToolsItemCountForId(wd.SKILL_ADVANCED_DRUG_ID)
	return count
end

function SkillDataHandler:checkCanUpGrade(tag,upgradeType)
	if tag and self.mySkillList[tag] and self.mySkillList[tag].skillItem then
		if self.mySkillList[tag].skillItem:getLevel() + 1 == wd.FULL_LEVEL then	 -- Advanced
			if upgradeType == wd.UpgradeType.eUpgrade then
				return self:getSkillAdvancedDrugCount() >= 1
			end
		else	-- Upgrade
			if upgradeType == wd.UpgradeType.eUpgrade then
				return self:getSkillUpgradeDrugCount() >= 1
			else
				return self:getSkillUpgradeDrugCount() >= 10
			end
		end
	end
end

-- 请求技能升级
function SkillDataHandler:requestUpgradeSkill(tag,upgradeType)
	if tag and self.mySkillList[tag] and self.mySkillList[tag].skillItem then
		if upgradeType == wd.UpgradeType.eUpgrade then	
			wd.TranscodingSend:upSkillLevel(wd.UseDurgNumber.eOnce,self.mySkillList[tag].skillItem:getSkillId())
		elseif upgradeType == wd.UpgradeType.eAutoUpgrade then	
			wd.TranscodingSend:upSkillLevel(wd.UseDurgNumber.eAuto,self.mySkillList[tag].skillItem:getSkillId())
		end
		self.requsetUpgradeTag = tag
		self.requsetUpgradeType = upgradeType
	end
end

function SkillDataHandler:registerEventListener()
	--从服务器接收技能列表回调
	local function skillGetAllSkillCallBack(EventCustom)
		self.learnedSkillIdList = {}
		local learnedSkillCount = wd.GlobalData:getInstance():getSkillListItemCount()
		for i = 0,learnedSkillCount-1 do
			local learnedSkillItem = wd.GlobalData:getInstance():getSkillListItem(i)
			local skillId = learnedSkillItem:getSkillId()
			local exp = learnedSkillItem:getExp()
			if type(skillId) == "number" and type(exp) == "number" then
				local skill = {}
				skill.skillId = skillId
				skill.exp = exp
				table.insert(self.learnedSkillIdList,skill)
			end
		end
		self:setMySkillList()
	end
	
	local function skillUseCallBack(EventCustom)
		wd.showRichTips(4,"设置成功")
		--技能顺序设置成功
		self.skillOrderIdList = self.requsetOrderIdList
		self:setSkillOrderList()
	end
	
	local function skillUpgradeCallBack(EventCustom)
		
		--技能升级成功
		local upgradedSkill = wd.GlobalData:getInstance():getUpgradedSkill()
		local upgradedSkillItem = self:getSkillItemBySkillId(upgradedSkill:getSkillId())
		if upgradedSkillItem and self.requsetUpgradeTag then
			local curSkillItemId = self.mySkillList[self.requsetUpgradeTag].skillItem:getSkillId()
			local skill = {}
			local isUpgrade = false
			skill.exp = upgradedSkill:getExp()
			skill.isLearned = true
			skill.skillItem = upgradedSkillItem
			self.mySkillList[self.requsetUpgradeTag] = skill
			local event = cc.EventCustom:new("Update_SkillData")
			event.tag = self.requsetUpgradeTag
			cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
			if upgradedSkill:getSkillId() ~= curSkillItemId then	--升级了
				isUpgrade = true
				event = cc.EventCustom:new("Update_SkillList")
				event.tag = self.requsetUpgradeTag
				cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
				
				-- 处理技能顺序列表数据
				local isChanged = false
				for i,v in ipairs(self.skillOrderIdList) do
					if math.abs(tonumber(v) - tonumber(upgradedSkillItem:getSkillId())) < 30 then
						self.skillOrderIdList[i] = upgradedSkillItem:getSkillId()
						isChanged = true
					end
				end
				if isChanged then
					self:setSkillOrderList()
					event = cc.EventCustom:new("Update_SkillList")
					cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
				end
			end
			if isUpgrade then
				wd.showRichTips(4,"技能等级提升")
			else
				if self.requsetUpgradeType == wd.UpgradeType.eUpgrade then	
					wd.showRichTips(4,"获得100点熟练度")
				elseif self.requsetUpgradeType == wd.UpgradeType.eAutoUpgrade then	
					wd.showRichTips(4,"获得1000点熟练度")
				end
				
			end
		end
	end
	
	local listenerGetAllSkill = cc.EventListenerCustom:create("Skill_GetAllCanUseSkill", skillGetAllSkillCallBack)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listenerGetAllSkill, 1); 
	
	local listenerSkillUse = cc.EventListenerCustom:create("Skill_Use", skillUseCallBack)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listenerSkillUse, 1); 
	
	local listenerSkillUpgrade = cc.EventListenerCustom:create("Skill_Up", skillUpgradeCallBack)
	cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listenerSkillUpgrade, 1); 
end


--------------------------------------------------buff---------------------------------------------------------

function SkillDataHandler:setAllBuffInfo()
	local buffCount = wd.GlobalData:getInstance():getBuffItemCount()
	for i = 0,buffCount-1 do 
		local buffItem = wd.GlobalData:getInstance():getBuffItem(i)
		if buffItem then
			self.allBuffItem[buffItem:getBuffId()] = buffItem
		end
	end
end

function SkillDataHandler:getBuffItemById(buffId)
	if self.allBuffItem[buffId] then
		return self.allBuffItem[buffId]
	end
end

return SkillDataHandler