
local SoulGetLayer = class("SoulGetLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function SoulGetLayer.create()
    local layer = SoulGetLayer.new()
    return layer
end

function SoulGetLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
	self.boxBinding = 86
	self.gapX = 80
	self.gapY = 40
end

function SoulGetLayer:createLayerMenu(getType)
    local node = tolua.cast(cc.CSLoader:createNode("ui/package/soul/BuySoulLayer.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)
	
	local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Main"), "ccui.Widget")
	
    local toolsCount = 0  
    local setupTools = require("src.game.package.SetupTools")
	local getData = wd.GlobalData:getInstance():getMessage("Get_Item")
    local btnTable = {}
    local btn
    while(string.len(getData)>=5) do
        local startIndex,lastIndex,type,id,count  = string.find(getData,"(%d+)#(%d+)|(%d+)")

        if type == nil or id == nil or count == nil then
            break
        end

        type = tonumber(type)
        id = tonumber(id)
        count = tonumber(count)
        
        if count > 0 then
            if type == wd.ItemType.Tools then
                btn = setupTools:getTools(id, count)
            elseif type == wd.ItemType.Equip then
                btn = setupTools:getEquip(id, count)
            elseif type == wd.ItemType.Special then
                btn = setupTools:getSpecial(id, count)
            elseif type == wd.ItemType.Soul then
                btn = setupTools:getSoul(id,count)
            end
            toolsCount = toolsCount + 1
            table.insert(btnTable,btn)
        end
        getData = string.sub(getData,lastIndex+1,-1)
    end
        
	local itemPanel =  tolua.cast(ccui.Helper:seekWidgetByName(node,"Item_Panel"), "ccui.Widget")
	local itemStr = wd.GlobalData:getInstance():getBuySoulIdStr()
	local itemIdList = {}
	while (itemStr~= "") 
	do 
		local startIndex,endIndex,id = string.find(itemStr,"(%d+),")
		if id then
			table.insert(itemIdList,tonumber(id))
			itemStr = string.sub(itemStr,endIndex+1,-1)
		end
	end
	
	local count = #itemIdList
	local row = count + toolsCount > 5 and count + toolsCount -5 or count + toolsCount
	local startX = (itemPanel:getContentSize().width - self.boxBinding*row - self.gapX*(row-1))/2
	local startY
	if (count + toolsCount) > 5 then
		startY = (itemPanel:getContentSize().height - self.boxBinding*2 - self.gapY)/2
	else
		startY = itemPanel:getContentSize().height/2 - self.boxBinding/2
	end
	for i,v in ipairs(itemIdList) do
		local soulItem = wd.GlobalData:getInstance():getSoulItemForId(v)
		if soulItem then
			local soulNode = tolua.cast(cc.CSLoader:createNode("ui/package/soul/SoulNode.csb"), "ccui.Widget")
			local image = tolua.cast(soulNode:getChildByName("Soul_Sprite"), "cc.Sprite")
			image:setSpriteFrame(string.format("%d.png",soulItem:getSoulId()))
			wd.soulEffect(soulItem:getQuality(),image)
			
			local color = soulItem:getGrade()
			local colorSprite = tolua.cast(soulNode:getChildByName("Color_Sprite"), "cc.Sprite")
			colorSprite:setSpriteFrame(string.format("%02d.png",color))

			local gradeLabel = tolua.cast(soulNode:getChildByName("Grade_Label"), "ccui.Text")
			gradeLabel:setString(soulItem:getGrade())
			
			local nameLabel = tolua.cast(soulNode:getChildByName("Name_Label"), "ccui.Text")
            nameLabel:setColor(wd.colorType(color))
            
            if soulItem:getSoulGrade() >0 then
                nameLabel:setString(string.format("%s+%d",soulItem:getName(), soulItem:getSoulGrade()))
            else
                nameLabel:setString(soulItem:getName())
            end
			local levelLabel = tolua.cast(soulNode:getChildByName("Level_Label"), "ccui.TextBMFont")
			local levelBox = tolua.cast(soulNode:getChildByName("Level_Box"), "cc.Sprite")
			levelLabel:setVisible(false)
			levelBox:setVisible(false)
			itemPanel:addChild(soulNode)
			local xIndex = (i>5 and i-5 or i)
			soulNode:setPosition(startX+(xIndex-1)*(self.boxBinding+self.gapX),startY+(self.boxBinding+self.gapY)*math.floor((i-1)/5))
		end
	end
    
    for i,v in ipairs(btnTable) do
        local xIndex = ((i + #itemIdList)>5 and (i + #itemIdList)-5 or (i + #itemIdList))
        itemPanel:addChild(v)
        v:setPosition(startX+(xIndex-1)*(self.boxBinding+self.gapX),startY+(self.boxBinding+self.gapY)*math.floor((i + #itemIdList -1)/5))
    end
    
	
    local backBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Close_Button"), "ccui.Widget")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:removeFromParent()
				
            end
        end
    )

	local trialOneBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Soul_Trial_1_Button"), "ccui.Widget")
    trialOneBtn:setPressedActionEnabled(true)
    trialOneBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                wd.soulHandler:requestBuySoul(1)
				self:removeFromParent()
            end
        end
    )
	local trialFiveBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Soul_Trial_5_Button"), "ccui.Widget")
    trialFiveBtn:setPressedActionEnabled(true)
    trialFiveBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                wd.soulHandler:requestBuySoul(2)
				self:removeFromParent()
            end
        end
    )
	local prayOneBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Soul_Pray_1_Button"), "ccui.Widget")
    prayOneBtn:setPressedActionEnabled(true)
    prayOneBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                wd.soulHandler:requestBuySoul(3)
				self:removeFromParent()
            end
        end
    )
	local prayTenBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Soul_Pray_10_Button"), "ccui.Widget")
    prayTenBtn:setPressedActionEnabled(true)
    prayTenBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                wd.soulHandler:requestBuySoul(4)
				self:removeFromParent()
            end
        end
    )
	local isTrail = true
	if getType == 2 then
		isTrail = false
	end
	trialOneBtn:setVisible(isTrail)
	trialFiveBtn:setVisible(isTrail)
	prayOneBtn:setVisible(not isTrail)
	prayTenBtn:setVisible(not isTrail)
end


return SoulGetLayer