
local SoulShopLayer = class("SoulShopLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function SoulShopLayer.create()
    local layer = SoulShopLayer.new()
    layer:createLayerMenu()
    return layer
end

function SoulShopLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil
	self.pressTime = 0
end

function SoulShopLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/package/soul/SoulShopScene.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)
	
	local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Main"), "ccui.Widget")
	
    local backBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Close_Button"), "ccui.Widget")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				local event = cc.EventCustom:new("Check_New_Tip")
				cc.Director:getInstance():getEventDispatcher():dispatchEvent(event)
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Buy_Soul")
				if self.sequenceAction then
					self.sequenceAction:release()
					self.sequenceAction = nil
				end
                self:removeFromParent()
            end
        end
    )
	
	local showList = wd.soulHandler:getSoulShowList()
	for i,v in ipairs(showList) do
        if i >=5 then
            break 
        end
		local soulNode = tolua.cast(mainPanel:getChildByName(string.format("Soul_Node_%d",i)),"ccui.Widget")
		local soulBtn = tolua.cast(soulNode:getChildByName("Soul_Button"),"ccui.Widget")
		-- soulBtn:setPressedActionEnabled(true)
		soulBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				local layerClass = require("src.game.soul.SoulTipsLayer")
				local layer = layerClass.create()
				layer:createLayerMenu(v,0)
				self:addChild(layer)
            end
        end)
		local colorSprite = tolua.cast(soulNode:getChildByName("Color_Sprite"),"cc.Sprite")
		colorSprite:setSpriteFrame(string.format("%02d.png",v.grade))
		local soulSprite = tolua.cast(soulNode:getChildByName("Soul_Sprite"),"cc.Sprite")
		soulSprite:setSpriteFrame(string.format("%d.png",v.id))
		wd.soulEffect(v.quality,soulSprite)
		local gradeLabel = tolua.cast(soulNode:getChildByName("Grade_Label"),"ccui.Text")
		gradeLabel:setString(v.grade)
		local levelBox = tolua.cast(soulNode:getChildByName("Level_Box"),"cc.Sprite")
		local levelLabel = tolua.cast(soulNode:getChildByName("Level_Label"),"ccui.Text")
		levelBox:setVisible(false)
		levelLabel:setVisible(false)
	end
    
    local function attrCallback(sender,eventType)
        if eventType == ccui.TouchEventType.ended then
            local layerClass = require("src.game.package.ToolsTipsLayer")
            local layer = layerClass.create()
            layer:createLayerMenu(sender:getTag(),true)
            self:addChild(layer)
        end
    end
    
    tolua.cast(mainPanel:getChildByName("soul_btn_1"),"ccui.Button"):setTag(wd.ItemId.SoulSpecial_1)
    tolua.cast(mainPanel:getChildByName("soul_btn_2"),"ccui.Button"):setTag(wd.ItemId.SoulSpecial_2)
    tolua.cast(mainPanel:getChildByName("soul_btn_1"),"ccui.Button"):addTouchEventListener(attrCallback)
    tolua.cast(mainPanel:getChildByName("soul_btn_2"),"ccui.Button"):addTouchEventListener(attrCallback)
    local soulFive = wd.GlobalData:getInstance():getToolsItemInXml(wd.ItemId.SoulSpecial_1)
    local soulSix = wd.GlobalData:getInstance():getToolsItemInXml(wd.ItemId.SoulSpecial_2)
    local soul5 = tolua.cast(mainPanel:getChildByName("soul_1"),"ccui.Widget")
    local soul6 = tolua.cast(mainPanel:getChildByName("soul_2"),"ccui.Widget")
    tolua.cast(soul5:getChildByName("Number_Label"),"cc.Sprite"):setVisible(false)
    tolua.cast(soul6:getChildByName("Number_Label"),"cc.Sprite"):setVisible(false)
    tolua.cast(soul5:getChildByName("Item_Sprite"),"cc.Sprite"):setSpriteFrame(string.format("%d.png",soulFive:getToolsId()))
    tolua.cast(soul6:getChildByName("Item_Sprite"),"cc.Sprite"):setSpriteFrame(string.format("%d.png",soulSix:getToolsId()))
    tolua.cast(soul5:getChildByName("Color_Sprite"),"cc.Sprite"):setSpriteFrame(string.format("%02d.png",soulFive:getQuality()))
    tolua.cast(soul6:getChildByName("Color_Sprite"),"cc.Sprite"):setSpriteFrame(string.format("%02d.png",soulSix:getQuality()))
    
    
	local prayEffect =  tolua.cast(mainPanel:getChildByName("Soul_Pray_Effect"),"cc.Sprite")
	
	local function playAnimation()
		if self.sequenceAction and (not self.sequenceAction:isDone()) then
			return
		end
		if not prayEffect then
			return
		end
		prayEffect:setVisible(true)
		local animation = cc.Animation:create()
		for i = 1, 10 do
			animation:addSpriteFrame(cc.SpriteFrameCache:getInstance():getSpriteFrame(string.format("soulPray_%02d.png", i)))
		end

		animation:setDelayPerUnit(0.08)
		animation:setLoops(1)
		local action = cc.Animate:create(animation)
		
		local function delayCallBackFunc(sender)
			prayEffect:setVisible(false)
			self:showGetLayer()
		end

		local delayCallBack = cc.CallFunc:create(delayCallBackFunc)
		self.sequenceAction = cc.Sequence:create(action, delayCallBack)
		self.sequenceAction:retain()
		prayEffect:runAction(self.sequenceAction)
	end
	
	local trialOneBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Soul_Trial_1_Button"), "ccui.Widget")
    trialOneBtn:setPressedActionEnabled(true)
    trialOneBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				if math.abs(self.pressTime - os.time()) > 2 then
					self.pressTime = os.time()
					wd.soulHandler:requestBuySoul(1)
					self.getType = 1
				end
            end
        end
    )
	local trialFiveBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Soul_Trial_5_Button"), "ccui.Widget")
    trialFiveBtn:setPressedActionEnabled(true)
    trialFiveBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				if math.abs(self.pressTime - os.time()) > 2 then
                    if wd.GlobalData:getInstance():getRoleGem() < 320 then
                        local layerClass = require("src.game.charge.ChargeTipsScene")
                        local layer = layerClass:create()
                        self:getParent():addChild(layer)
                    else
                        self.pressTime = os.time()
                        wd.soulHandler:requestBuySoul(2)
                        self.getType = 1
                    end
				end
                
            end
        end
    )
	local prayOneBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Soul_Pray_1_Button"), "ccui.Widget")
    prayOneBtn:setPressedActionEnabled(true)
    prayOneBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				if math.abs(self.pressTime - os.time()) > 2 then
                    if wd.GlobalData:getInstance():getRoleGem() < 280 then
                        local layerClass = require("src.game.charge.ChargeTipsScene")
                        local layer = layerClass:create()
                        self:getParent():addChild(layer)
                    else
                        self.pressTime = os.time()
                        wd.soulHandler:requestBuySoul(3)
                        self.getType = 2
                    end
				end
            end
        end
    )
	local prayTenBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Soul_Pray_10_Button"), "ccui.Widget")
    prayTenBtn:setPressedActionEnabled(true)
    prayTenBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
				if math.abs(self.pressTime - os.time()) > 2 then
                    if wd.GlobalData:getInstance():getRoleGem() < 2500 then
                        local layerClass = require("src.game.charge.ChargeTipsScene")
                        local layer = layerClass:create()
                        self:getParent():addChild(layer)
                    else
                        self.pressTime = os.time()
                        wd.soulHandler:requestBuySoul(4)
                        self.getType = 2
                    end
				end
            end
        end
    )
	
	local function onBuySoul(EventCustom)
        playAnimation()
		if cc.UserDefault:getInstance():getBoolForKey("Sound") then
			cc.SimpleAudioEngine:getInstance():playEffect(cc.FileUtils:getInstance():fullPathForFilename("res/music/luckEffect.mp3"), false)
		end
    end
	
	local listener = cc.EventListenerCustom:create("Buy_Soul", onBuySoul)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);

end

function SoulShopLayer:showGetLayer()
	local layerClass = require("src.game.soul.SoulGetLayer")
	local layer = layerClass.create()
	layer:createLayerMenu(self.getType)
	self:addChild(layer)
end

return SoulShopLayer