local SwallowLayer = class("SwallowLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function SwallowLayer.create()
    local layer = SwallowLayer.new()
    layer:createLayerMenu()
    return layer
end

function SwallowLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.initSelect = true
	self.selectTag = 1
	self.wearRegion = nil
	self.equipNodeTable = {}
	self.expTable = {}
end

function SwallowLayer:addEquip()
    local count = 0
    local number = wd.GlobalData:getInstance():getEquipItemCount()-1
    local itemTable = {}
    
    for i = 0,number do
        local item = wd.GlobalData:getInstance():getEquipItem(number-i)
        if item ~= nil then
            if item:getLocked() == 0 and (item:getQuality() == 2 or item:getQuality() == 3) then
                itemTable[count] = item
                count = count + 1
                if count >= 4 then
                    break
                end
            end
        end
    end
    
    if count == 0 then
		wd.showRichTips(4,"背包中没有未加锁的神器")
		return
	end
    for i = 0,3 do
    
        local item = itemTable[i]
        
        local colorSprite = tolua.cast(self.equipNodeTable[i]:getChildByName("Color_Sprite"), "cc.Sprite")
        local equipSprite = tolua.cast(self.equipNodeTable[i]:getChildByName("Equip_Sprite"), "cc.Sprite")        
        local levelLabel = tolua.cast(self.equipNodeTable[i]:getChildByName("Level_Label"), "ccui.TextBMFont")
        local title = tolua.cast(self.equipNodeTable[i]:getChildByName("Job_Title"), "cc.Sprite")
        local strengthenLabel = tolua.cast(self.equipNodeTable[i]:getChildByName("Strengthen_Label"), "ccui.Text")
		local swallowLabel = tolua.cast(self.equipNodeTable[i]:getChildByName("Swallow_Label"), "ccui.Text")

        equipSprite:removeAllChildren()
        if item ~= nil then

            self.equipNodeTable[i]:setTag(item:getServerId())
            
            self.equipNodeTable[i]:setVisible(true)
    
            colorSprite:setSpriteFrame(string.format("%02d.png",item:getColor()))
            equipSprite:setSpriteFrame(string.format("%d.png",item:getEquipId()%1000))
            levelLabel:setString(string.format("Lv%d",item:getLevel()))
            
            if item:getOccupation() <= 0 then
                title:setVisible(false)
            else
                title:setSpriteFrame(wd.getEquipTitleName(item:getOccupation()))
            end
            
            if item:getStrengthenLevel() > 0 then
                strengthenLabel:setString(string.format("+%d",item:getStrengthenLevel()))
            else
                strengthenLabel:setString("")
            end
			
			swallowLabel:setString(string.format("(%d)",item:getSwallowLevel()))
            
            wd.equipEffect(item, equipSprite)
			
			self.expTable[i] = item:getSwallowExp()+wd.GlobalData:getInstance():getEquipSwallowTotalExp(item:getSwallowLevel()-1)

        else
            self.equipNodeTable[i]:setTag(-1)
            self.equipNodeTable[i]:setVisible(false)
			self.expTable[i] = nil
        end
    end
	self:updateUseMoney()
	self:updateExp()
end

function SwallowLayer:clearEquip()
     for i = 0,3 do
        self.equipNodeTable[i]:setTag(-1)
        self.equipNodeTable[i]:setVisible(false)
     end
	self.expTable = {}
	self:updateUseMoney()
end

function SwallowLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/tripod/SwallowScene.csb"), "ccui.Widget")
    self:addChild(node)

    self.mainNode = node
    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)
    ccui.Helper:doLayout(node)


    local backBtn = ccui.Helper:seekWidgetByName(node,"Back_Button")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:removeFromParent()
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Tripod_Swallow")
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Item_Msg")
            end
        end
    )
    
    local meltingBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Melting_Button"), "ccui.Button")
    meltingBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                local layerClass = require("src.game.tripod.MeltingLayer")
                local layer = layerClass.create()
                self:getParent():addChild(layer)
                self:removeFromParent()
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Tripod_Swallow")
				cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Item_Msg")
            end
        end
    )
	
	-- local smeltingBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Smelting_Button"), "ccui.Button")
    -- smeltingBtn:addTouchEventListener(
    --     function(sender,eventType)
    --         if eventType == ccui.TouchEventType.ended then
    --             local layerClass = require("src.game.tripod.SmeltingLayer")
    --             local layer = layerClass.create()
    --             self:getParent():addChild(layer)
    --             self:removeFromParent()
	-- 			cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Tripod_Swallow")
	-- 			cc.Director:getInstance():getEventDispatcher():removeCustomEventListeners("Get_Item_Msg")
    --         end
    --     end
    -- )
	
    local mainPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Box"), "ccui.Widget")
	
	local levelPanel = tolua.cast(ccui.Helper:seekWidgetByName(node,"Panel_Level"), "ccui.Widget")
	self.expBar = tolua.cast(ccui.Helper:seekWidgetByName(levelPanel,"Exp_Progress"), "ccui.LoadingBar")
    self.expLabel = tolua.cast(ccui.Helper:seekWidgetByName(levelPanel,"Exp_Label"), "ccui.Text")
	
	
	self.panelSwallow = tolua.cast(ccui.Helper:seekWidgetByName(mainPanel,"Panel_Swallow"), "ccui.Widget")
	self.middleEquip = tolua.cast(self.panelSwallow:getChildByName("Equip_Middle_Node"), "ccui.Widget")
	self.panelUse = tolua.cast(ccui.Helper:seekWidgetByName(mainPanel,"Panel_Use"), "ccui.Widget")
	self.equipNodeTable[0] = tolua.cast(self.panelSwallow:getChildByName("Equip0_Node"), "cc.Node")
    self.equipNodeTable[1] = tolua.cast(self.panelSwallow:getChildByName("Equip1_Node"), "cc.Node")
    self.equipNodeTable[2] = tolua.cast(self.panelSwallow:getChildByName("Equip2_Node"), "cc.Node")
    self.equipNodeTable[3] = tolua.cast(self.panelSwallow:getChildByName("Equip3_Node"), "cc.Node")
    
    local function removeEquip (sender,eventType)
        if eventType == ccui.TouchEventType.ended then
            self.equipNodeTable[sender:getTag()]:setTag(-1)
            self.equipNodeTable[sender:getTag()]:setVisible(false)
			self.expTable[sender:getTag()] = nil
			self:updateUseMoney()
			self:updateExp()
        end
    end
    
    local equip0Btn =  tolua.cast(self.panelSwallow:getChildByName("Equip0_Button"), "ccui.Button")
    local equip1Btn =  tolua.cast(self.panelSwallow:getChildByName("Equip1_Button"), "ccui.Button")
    local equip2Btn =  tolua.cast(self.panelSwallow:getChildByName("Equip2_Button"), "ccui.Button")
    local equip3Btn =  tolua.cast(self.panelSwallow:getChildByName("Equip3_Button"), "ccui.Button")
    equip0Btn:addTouchEventListener(removeEquip)
    equip1Btn:addTouchEventListener(removeEquip)
    equip2Btn:addTouchEventListener(removeEquip)
    equip3Btn:addTouchEventListener(removeEquip)
	
	local addEquipBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"AddEquip_Button"), "ccui.Button")
    addEquipBtn:setPressedActionEnabled(true)
    addEquipBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:addEquip()
            end
        end
    )
	
	local curLvLabel = tolua.cast(self.panelSwallow:getChildByName("Current_Label"), "ccui.Text") 
	local nextLvLabel = tolua.cast(self.panelSwallow:getChildByName("Next_Label"), "ccui.Text")
	local curAttrLabel = tolua.cast(self.panelSwallow:getChildByName("Current_Attr"), "ccui.Text")
	local nextAttrLabel = tolua.cast(self.panelSwallow:getChildByName("Next_Attr"), "ccui.Text")
	local function updateData()
		if self.middleEquip:getTag() >= 0 then
			local equip = wd.GlobalData:getInstance():getWearEquipForId(self.middleEquip:getTag())
			if equip then
				local region = equip:getRegion()
				local curExp = equip:getSwallowExp()
				local curLevel = equip:getSwallowLevel()
				
				curLvLabel:setString(string.format("神器灵性【%d】",curLevel))
				curAttrLabel:setString(wd.GlobalData:getInstance():getEquipSwallowAttrByRegion(curLevel-1,region))
				if curLevel ~= 10 then
					nextLvLabel:setString(string.format("神器灵性【%d】",curLevel+1))
					nextAttrLabel:setString(wd.GlobalData:getInstance():getEquipSwallowAttrByRegion(curLevel,region))
					local needExp = wd.GlobalData:getInstance():getEquipSwallowNeedExp(curLevel)
					self.expLabel:setString(string.format("%d/%d",curExp,needExp))
					self.expBar:setPercent(curExp/needExp*100)
				else
					nextLvLabel:setString("已满级")
					nextAttrLabel:setString("已满级")
					self.expLabel:setString("已满级")
					self.expBar:setPercent(100)
				end
			else
				curLvLabel:setString("")
				curAttrLabel:setString("")
				nextLvLabel:setString("")
				nextAttrLabel:setString("")
				self.expBar:setPercent(0)
			end
		end
		self:clearEquip()
	end
	
	local itemList =  tolua.cast(ccui.Helper:seekWidgetByName(node,"Equip_List"), "ccui.ListView")
	
	local function setSwallowEquip(sender,eventType)
        if eventType == ccui.TouchEventType.ended then
			wd.setSelectBox(itemList,self.selectTag,sender:getTag())
			self.selectTag = sender:getTag()
            self.wearRegion = sender:getTag()
            self:showSwallowEquip(self.wearRegion)
            updateData()
            
        end
    end
	
	
	for i=wd.WearRegion.WEAPON,wd.WearRegion.RRING do
    
        local item = wd.GlobalData:getInstance():getWearEquip(i)
        
        if item ~= nil and (item:getQuality() == 2 or item:getQuality() == 3) then
    
            local equipNode = tolua.cast(cc.CSLoader:createNode("ui/tripod/SmeltingNode.csb"),"ccui.Widget")
    
            local btn = ccui.Button:create("smelting_item_box.png", "smelting_item_box.png", "", ccui.TextureResType.plistType)
            btn:setAnchorPoint(cc.p(0,0))
            btn:setTag(i)
            btn:addTouchEventListener(setSwallowEquip)
			equipNode:setTag(i)
            btn:addChild(equipNode)
			
			local selectBox = tolua.cast(equipNode:getChildByName("Select_Sprite"), "cc.Sprite")
			if self.initSelect then
				selectBox:setVisible(true)
				self.initSelect = false
				self.wearRegion = i
                self.selectTag = i
			else
				selectBox:setVisible(false)
			end
					
            local image = tolua.cast(equipNode:getChildByName("Equip_Sprite"), "cc.Sprite")
            image:setSpriteFrame(string.format("%d.png",item:getEquipId()%1000))
            wd.equipEffect(item, image)
            
            local color = tolua.cast(equipNode:getChildByName("Color_Sprite"), "cc.Sprite")
            color:setSpriteFrame(string.format("%02d.png",item:getColor()))
            
            local title = tolua.cast(equipNode:getChildByName("Job_Title"), "cc.Sprite")
            if item:getOccupation() <= 0 then
                title:setVisible(false)
            else
                title:setSpriteFrame(wd.getEquipTitleName(item:getOccupation()))
            end
    
            local levelLabel = tolua.cast(equipNode:getChildByName("Level_Label"), "ccui.TextBMFont")
            levelLabel:setString(string.format("Lv%d",item:getLevel()))
    
            local nameLabel = tolua.cast(equipNode:getChildByName("Name_Label"), "ccui.Text")
            nameLabel:setColor(wd.colorType(item:getColor()))
            if item:getStrengthenLevel() >0 then
                nameLabel:setString(string.format("%s+%d",item:getName(), item:getStrengthenLevel()))
            else
                nameLabel:setString(item:getName())
            end
                
            local regionLabel = tolua.cast(equipNode:getChildByName("Region_Label"), "ccui.Text")
            regionLabel:setString(string.format("位置：%s",wd.getRegionString(item:getRegion())))
    
            itemList:pushBackCustomItem(btn)
        end
    end
	
	local doSwallowBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"DoSwallow_Button"), "ccui.Button")
    doSwallowBtn:setPressedActionEnabled(true)
    doSwallowBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                if self.middleEquip:getTag() >= 0 and (self.equipNodeTable[0]:getTag() >= 0 or self.equipNodeTable[1]:getTag() >= 0 or self.equipNodeTable[2]:getTag() >= 0 or self.equipNodeTable[3]:getTag() >= 0 )then
                    wd.TranscodingSend:setTripodSwallow(self.equipNodeTable[0]:getTag(),self.equipNodeTable[1]:getTag(),self.equipNodeTable[2]:getTag(),self.equipNodeTable[3]:getTag(),self.middleEquip:getTag())
                else
                    wd.showRichTips(4,"请添加升灵所需装备")
                end
            end
        end
    )
	self:showSwallowEquip(self.wearRegion)
	
	
	
	updateData() 
	
	local listener = cc.EventListenerCustom:create("Tripod_Swallow", updateData)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
	local function getCallback(EventCustom)
        local getData = wd.GlobalData:getInstance():getMessage("Get_Item_Msg")
        local list = wd.getItemInfoList(getData)
        for k,itemInfo in pairs(list) do
            if itemInfo~= nil and itemInfo.name ~= nil and itemInfo.color ~= nil and itemInfo.count ~= nil then
                local msg = {}
                table.insert(msg,"获得")
                table.insert(msg,string.format("{t=[%s],c=[%d]}",itemInfo.name,itemInfo.color))
                table.insert(msg,string.format("*%d",itemInfo.count))
                wd.showRichTips(wd.tipsType.Get,msg)
            end
        end
    end
	
	local listener = cc.EventListenerCustom:create("Get_Item_Msg", getCallback)
    cc.Director:getInstance():getEventDispatcher():addEventListenerWithFixedPriority(listener, 1);
	
end


function SwallowLayer:showSwallowEquip(tag)

    if tag == nil then
        return
    end
    
    
	local colorSprite = tolua.cast(self.middleEquip:getChildByName("Color_Sprite"), "cc.Sprite")
	local equipSprite = tolua.cast(self.middleEquip:getChildByName("Equip_Sprite"), "cc.Sprite")        
	local levelLabel = tolua.cast(self.middleEquip:getChildByName("Level_Label"), "ccui.TextBMFont")
	local title = tolua.cast(self.middleEquip:getChildByName("Job_Title"), "cc.Sprite")
	local strengthenLabel = tolua.cast(self.middleEquip:getChildByName("Strengthen_Label"), "ccui.Text")
    
	
	local item = wd.GlobalData:getInstance():getWearEquip(tag)
	
	if item ~= nil then
		self.middleEquip:setVisible(true)
		self.middleEquip:setTag(item:getServerId())
		colorSprite:setSpriteFrame(string.format("%02d.png",item:getColor()))
		equipSprite:setSpriteFrame(string.format("%d.png",item:getEquipId()%1000))
		levelLabel:setString(string.format("Lv%d",item:getLevel()))
		
		if item:getOccupation() <= 0 then
			title:setVisible(false)
		else
			title:setSpriteFrame(wd.getEquipTitleName(item:getOccupation()))
		end
		
		if item:getStrengthenLevel() > 0 then
			strengthenLabel:setString(string.format("+%d",item:getStrengthenLevel()))
		else
			strengthenLabel:setString("")
		end
		
		wd.equipEffect(item, equipSprite)
	else
		self.middleEquip:setVisible(false)
		self.middleEquip:setTag(-1)
	end
end

function SwallowLayer:updateUseMoney()
	local numberLabel = tolua.cast(ccui.Helper:seekWidgetByName(self.panelUse,"Number_Label"), "ccui.Widget")
	local totalExp = 0
	for i = 0,3 do
		if self.expTable[i] ~= nil then
			totalExp = totalExp + self.expTable[i]
		end
	end
	numberLabel:setString(string.format("：%d",totalExp*20000))
end

function SwallowLayer:updateExp()
	if self.middleEquip:getTag() >= 0 then
		local totalExp = 0
		for i = 0,3 do
			if self.expTable[i] ~= nil then
				totalExp = totalExp + self.expTable[i]
			end
		end
		local equip = wd.GlobalData:getInstance():getWearEquipForId(self.middleEquip:getTag())
		if equip then
			local curExp = equip:getSwallowExp()
			totalExp = totalExp + curExp
			local curLevel = equip:getSwallowLevel()
			if curLevel ~= 10 then
				local needExp = wd.GlobalData:getInstance():getEquipSwallowNeedExp(curLevel)
				self.expLabel:setString(string.format("%d/%d",totalExp,needExp))
				if totalExp >= needExp then
					self.expBar:setPercent(100)
				else
					self.expBar:setPercent(totalExp/needExp*100)
				end
			else
				self.expLabel:setString("已满级")
				self.expBar:setPercent(100)
			end
		end
	end
end

return SwallowLayer