local AREAMAX = 50

local AreaLayer = class("AreaLayer",function()
    return cc.Layer:create()
end)

-- cclog
local cclog = function(...)
    print(string.format(...))
end

function AreaLayer.create()
    local layer = AreaLayer.new()
    layer:createLayerMenu()
    return layer
end

function AreaLayer:ctor()
    self.visibleSize = cc.Director:getInstance():getVisibleSize()
    self.origin = cc.Director:getInstance():getVisibleOrigin()
    self.schedulerID = nil

end

function AreaLayer:setArea(tag)
    self:getParent():setServerId(tag)
    self:removeFromParent()
end

function AreaLayer:showMarkServer(markNode, area)
    if self.getMarkNode then
        return
    end
    local function btnCallback(sender,eventType)
        if eventType == ccui.TouchEventType.ended then
            self:setArea(sender:getTag())
        end
    end

    if area > 0 then
        self.getMarkNode = true
        local server = wd.GlobalData:getInstance():getGameServerForId(area)
        if server ~= nil then
            local btn = ccui.Button:create("login_server_mark.png", "login_server_mark.png", "", ccui.TextureResType.plistType)
            btn:setPressedActionEnabled(true)
            btn:setAnchorPoint(cc.p(0,0))
            btn:setTag(server:getServerId())
            btn:setScale9Enabled(true)
            btn:addTouchEventListener(btnCallback)
    
            local serverNode = tolua.cast(cc.CSLoader:createNode("ui/login/MarkNode.csb"),"ccui.Widget")
            btn:addChild(serverNode)
    
            local nameLabel = tolua.cast(serverNode:getChildByName("Name_Label"), "ccui.Text")
            nameLabel:setString(server:getName())
    
            local areaLabel = tolua.cast(serverNode:getChildByName("AreaNumber_Label"), "ccui.Text")
            areaLabel:setString(string.format("%d服",server:getServerId()))
            
            
            markNode:addChild(btn)
        end
    end
end

function AreaLayer:createLayerMenu()
    local node = tolua.cast(cc.CSLoader:createNode("ui/login/ServerLayer.csb"), "ccui.Widget")
    self:addChild(node)

    node:setContentSize(self.visibleSize)
    node:setPosition(self.origin)

    ccui.Helper:doLayout(node)
    
    
    local backBtn = tolua.cast(ccui.Helper:seekWidgetByName(node,"Back_Button"), "ccui.Widget")
    backBtn:setPressedActionEnabled(true)
    backBtn:addTouchEventListener(
        function(sender,eventType)
            if eventType == ccui.TouchEventType.ended then
                self:removeFromParent()
            end
        end
    )
    
    
    self.innerWidth = 535
    local number = wd.GlobalData:getInstance():getGameServerCount()
    local overViewNum = math.ceil(number / AREAMAX)
    self.areaId = overViewNum
    self.areaIdMax = overViewNum
    
    local function numberOfCells(tableview)
        local count = self.areaId - 1
        return self.areaId == overViewNum and math.ceil((number - AREAMAX * count)/2) or AREAMAX/2
    end
    
    local function cellSizeForTable(table,idx)
        return 100
    end
    local function tableCellAtIndexForce(table,idx)
        local cell = table:dequeueCell()
        local leftId,rightId,max,min
        if self.areaId == overViewNum and number % AREAMAX ~= 0 then
            local count = self.areaId - 1
            max = number
            min = AREAMAX * count
        else      
            max = AREAMAX * self.areaId
            min = 0
        end
        leftId = max - idx * 2
        rightId = leftId - 1
        if rightId == min then
            rightId = 0
        end
        if not cell then
            local function fn(id)
                self:setArea(id)
            end
            cell = require("src.login.AreaLayerItem"):createItem(leftId,rightId,self.innerWidth,fn)
        end  
        cell:setupData(leftId,rightId)
        return cell
    end
    
    local serverAreaNode = cc.TableView:create(cc.size(self.innerWidth,360))
    self.serverAreaNode = serverAreaNode
    serverAreaNode:setDirection(cc.SCROLLVIEW_DIRECTION_VERTICAL)
    serverAreaNode:setVerticalFillOrder(cc.TABLEVIEW_FILL_TOPDOWN)
    serverAreaNode:setDelegate()
    serverAreaNode:registerScriptHandler(numberOfCells,cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
    serverAreaNode:registerScriptHandler(cellSizeForTable,cc.TABLECELL_SIZE_FOR_INDEX)
    serverAreaNode:registerScriptHandler(tableCellAtIndexForce,cc.TABLECELL_SIZE_AT_INDEX)
    serverAreaNode:reloadData()

    serverAreaNode:setPosition(0,-360)
    local scrollViewNode = node:getChildByName("Panel_Main"):getChildByName("ScrollView_Node")
    scrollViewNode:addChild(serverAreaNode)       
     
    --设置最近登陆
    local markNode = node:getChildByName("Panel_Main"):getChildByName("Mark_Node")
    local area = cc.UserDefault:getInstance():getIntegerForKey("lastServer", 0)
    self:showMarkServer(markNode, area)    
    
    --设置大区切换
    local serverList = tolua.cast(ccui.Helper:seekWidgetByName(node,"Server_List"), "ccui.ListView")
    self:showServerList(serverList)
end

function AreaLayer:showServerList(serverList)
    if self.getServerList then
        return
    else
        self.getServerList = true
    end
    
    local btnNow  = self.areaIdMax
    local btnLast = self.areaIdMax
    local areaBtnList = {}
    local function btnCallback(sender,eventType)
        if eventType == ccui.TouchEventType.ended then
            btnLast = btnNow
            btnNow = sender:getTag()
            areaBtnList[self.areaIdMax + 1 - btnLast]:setScale(1)
            areaBtnList[self.areaIdMax + 1 - btnLast]:setTouchEnabled(true)
            areaBtnList[self.areaIdMax + 1 - btnNow]:setScale(1.1)
            areaBtnList[self.areaIdMax + 1 - btnNow]:setTouchEnabled(false)
            self.areaId = btnNow
            self.serverAreaNode:stopScroll()
            self.serverAreaNode:reloadData()
        end
    end

    for k = 1,self.areaIdMax do
        local index = self.areaIdMax + 1 - k
        local btn = ccui.Button:create("loading_server_list_btn.png", "loading_server_list_btn.png","", ccui.TextureResType.plistType)
        btn:setPressedActionEnabled(true)
        btn:setAnchorPoint(cc.p(0.5,0.5))
        btn:setScale9Enabled(true)
        btn:setContentSize(cc.size(190,70))
        btn:addTouchEventListener(btnCallback)
        btn:setTag(index)
        areaBtnList[k] = btn
    
        local listNode = tolua.cast(cc.CSLoader:createNode("ui/login/ListNode.csb"), "ccui.Widget")
        listNode:setPosition(cc.p(95,35))
        local areaLabelMin = tolua.cast(ccui.Helper:seekWidgetByName(listNode,"area_label_min"), "ccui.TextAtlas")
        local areaLabelMax = tolua.cast(ccui.Helper:seekWidgetByName(listNode,"area_label_max"), "ccui.TextAtlas")
        areaLabelMin:setString(AREAMAX * (index - 1) + 1)
        areaLabelMax:setString(AREAMAX * index)
        
        btn:addChild(listNode)
        
        serverList:pushBackCustomItem(btn)
    end
    areaBtnList[1]:setScale(1.1)
    areaBtnList[1]:setTouchEnabled(false)
end

return AreaLayer