local AreaLayerItem = class("AreaLayerItem",function()
    return cc.TableViewCell:create()
end)

function AreaLayerItem:createItem(leftId,rightId,innerWidth,fn)
    local item = self:create()
    self.touchBegan = 0
    self.touchended = false
    item:setupItem(leftId,rightId,innerWidth,fn)
    return item
end

function AreaLayerItem:setupItem(leftId,rightId,innerWidth,fn)
    
    local function btnCallback(sender,eventType)
        if eventType == ccui.TouchEventType.began then
            local pt = self:convertToWorldSpace(cc.p(sender:getPositionX(),sender:getPositionY()))
		    self.touchBegan = pt.y
            self.touchended = false
        elseif eventType == ccui.TouchEventType.moved then
            local pt = self:convertToWorldSpace(cc.p(sender:getPositionX(),sender:getPositionY()))
            if math.abs(pt.y - self.touchBegan) > 5 then
                self.touchended = true
            end
            if self.touchended then
                sender:setHighlighted(false)
            end
        end
        if eventType == ccui.TouchEventType.ended then
            fn(sender:getTag())
        end
    end
    
    self.btnLeft = ccui.Button:create("login_server_normal.png", "login_server_normal.png", "", ccui.TextureResType.plistType)
    self.btnLeft:setSwallowTouches(false)
    self.btnLeft:setPressedActionEnabled(true)
    self.btnLeft:setAnchorPoint(cc.p(0,0))
    self.btnLeft:addTouchEventListener(btnCallback)
    self.btnLeft:setPositionX((innerWidth/2 - self.btnLeft:getContentSize().width)/2)
    self:addChild(self.btnLeft)
    self.serverNodeLeft = tolua.cast(cc.CSLoader:createNode("ui/login/ServerNode.csb"),"ccui.Widget")
    self.btnLeft:addChild(self.serverNodeLeft)
    
    
    self.btnRight = ccui.Button:create("login_server_normal.png", "login_server_normal.png", "", ccui.TextureResType.plistType)
    self.btnRight:setSwallowTouches(false)
    self.btnRight:setPressedActionEnabled(true)
    self.btnRight:setAnchorPoint(cc.p(0,0))
    self.btnRight:addTouchEventListener(btnCallback)
    self.btnRight:setPositionX(innerWidth/2 + (innerWidth/2 - self.btnRight:getContentSize().width)/2)
    self:addChild(self.btnRight)
    self.serverNodeRight = tolua.cast(cc.CSLoader:createNode("ui/login/ServerNode.csb"),"ccui.Widget")
    self.btnRight:addChild(self.serverNodeRight)

end

function AreaLayerItem:setupData(leftId,rightId)
    --左按钮
    local server = wd.GlobalData:getInstance():getGameServerData(leftId - 1)
    self.btnLeft:setTag(server:getServerId())
    local nameLabel = tolua.cast(self.serverNodeLeft:getChildByName("Name_Label"), "ccui.Text")
    nameLabel:setString(server:getName())
    
    local areaLabel = tolua.cast(self.serverNodeLeft:getChildByName("AreaNumber_Label"), "ccui.Text")
    areaLabel:setString(string.format("%d服",server:getServerId()))

    local status = tolua.cast(self.serverNodeLeft:getChildByName("Status_Sprite"), "cc.Sprite")
    status:setSpriteFrame(wd.ServerStatusName[server:getStatus()])
    
    --右按钮
    if rightId ~= 0 then
        server = wd.GlobalData:getInstance():getGameServerData(rightId - 1)
        
        self.btnRight:setTag(server:getServerId())
        nameLabel = tolua.cast(self.serverNodeRight:getChildByName("Name_Label"), "ccui.Text")
        nameLabel:setString(server:getName())
        
        areaLabel = tolua.cast(self.serverNodeRight:getChildByName("AreaNumber_Label"), "ccui.Text")
        areaLabel:setString(string.format("%d服",server:getServerId()))

        status = tolua.cast(self.serverNodeRight:getChildByName("Status_Sprite"), "cc.Sprite")
        status:setSpriteFrame(wd.ServerStatusName[server:getStatus()])
        self.btnRight:setVisible(true)
    else
        self.btnRight:setVisible(false)
    end
end

return AreaLayerItem